Class: Aws::Drs::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
The request could not be completed due to a conflict with the current state of the target resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #code ⇒ String
- #message ⇒ String
-
#resource_id ⇒ String
The ID of the resource.
-
#resource_type ⇒ String
The type of the resource.
Instance Attribute Details
#code ⇒ String
82 83 84 85 86 87 88 89 |
# File 'lib/aws-sdk-drs/types.rb', line 82 class ConflictException < Struct.new( :code, :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
82 83 84 85 86 87 88 89 |
# File 'lib/aws-sdk-drs/types.rb', line 82 class ConflictException < Struct.new( :code, :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource.
82 83 84 85 86 87 88 89 |
# File 'lib/aws-sdk-drs/types.rb', line 82 class ConflictException < Struct.new( :code, :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource.
82 83 84 85 86 87 88 89 |
# File 'lib/aws-sdk-drs/types.rb', line 82 class ConflictException < Struct.new( :code, :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |