Class: Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_disposition ⇒ String
Launch disposition.
-
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
-
#recovery_mode ⇒ String
Recovery mode.
-
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Copy private IP.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_mode ⇒ String
Recovery mode.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-drs/types.rb', line 260 class CreateLaunchConfigurationTemplateRequest < Struct.new( :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |