Class: Aws::Drs::Types::CreateRecoveryPlanStepRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique string provided to ensure request idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-drs/types.rb', line 355

class CreateRecoveryPlanStepRequest < Struct.new(
  :recovery_plan_arn,
  :step_name,
  :step_order,
  :configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::RecoveryPlanStepConfiguration

Type-specific configuration for a recovery plan step. Exactly one member must be set.



355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-drs/types.rb', line 355

class CreateRecoveryPlanStepRequest < Struct.new(
  :recovery_plan_arn,
  :step_name,
  :step_order,
  :configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_plan_arnString

The ARN of the Recovery Plan to add the step to.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-drs/types.rb', line 355

class CreateRecoveryPlanStepRequest < Struct.new(
  :recovery_plan_arn,
  :step_name,
  :step_order,
  :configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_nameString

The name of a Recovery Plan Step.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-drs/types.rb', line 355

class CreateRecoveryPlanStepRequest < Struct.new(
  :recovery_plan_arn,
  :step_name,
  :step_order,
  :configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_orderInteger

The order of a step within a Recovery Plan (1-based).

Returns:

  • (Integer)


355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-drs/types.rb', line 355

class CreateRecoveryPlanStepRequest < Struct.new(
  :recovery_plan_arn,
  :step_name,
  :step_order,
  :configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end