Class: Aws::Drs::Types::DeleteReplicationConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::DeleteReplicationConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass DeleteReplicationConfigurationTemplateRequest data as a hash:
{
replication_configuration_template_id: "ReplicationConfigurationTemplateID", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#replication_configuration_template_id ⇒ String
The ID of the Replication Configuration Template to be deleted.
Instance Attribute Details
#replication_configuration_template_id ⇒ String
The ID of the Replication Configuration Template to be deleted.
384 385 386 387 388 |
# File 'lib/aws-sdk-drs/types.rb', line 384 class DeleteReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id) SENSITIVE = [] include Aws::Structure end |