Class: Aws::Drs::Types::DescribeJobLogItemsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass DescribeJobLogItemsRequest data as a hash:

{
  job_id: "JobID", # required
  max_results: 1,
  next_token: "PaginationToken",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_idString

The ID of the Job for which Job log items will be retrieved.

Returns:

  • (String)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-drs/types.rb', line 529

class DescribeJobLogItemsRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of Job log items to retrieve.

Returns:

  • (Integer)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-drs/types.rb', line 529

class DescribeJobLogItemsRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token of the next Job log items to retrieve.

Returns:

  • (String)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-drs/types.rb', line 529

class DescribeJobLogItemsRequest < Struct.new(
  :job_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end