Class: Aws::Drs::Types::DescribeSourceServersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::DescribeSourceServersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass DescribeSourceServersRequest data as a hash:
{
filters: {
hardware_id: "BoundedString",
source_server_i_ds: ["SourceServerID"],
staging_account_i_ds: ["AccountID"],
},
max_results: 1,
next_token: "PaginationToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::DescribeSourceServersRequestFilters
A set of filters by which to return Source Servers.
-
#max_results ⇒ Integer
Maximum number of Source Servers to retrieve.
-
#next_token ⇒ String
The token of the next Source Server to retrieve.
Instance Attribute Details
#filters ⇒ Types::DescribeSourceServersRequestFilters
A set of filters by which to return Source Servers.
888 889 890 891 892 893 894 |
# File 'lib/aws-sdk-drs/types.rb', line 888 class DescribeSourceServersRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of Source Servers to retrieve.
888 889 890 891 892 893 894 |
# File 'lib/aws-sdk-drs/types.rb', line 888 class DescribeSourceServersRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token of the next Source Server to retrieve.
888 889 890 891 892 893 894 |
# File 'lib/aws-sdk-drs/types.rb', line 888 class DescribeSourceServersRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |