Class: Aws::Drs::Types::Disk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::Disk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
An object representing a data storage device on a server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
-
#device_name ⇒ String
The disk or device name.
Instance Attribute Details
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
1131 1132 1133 1134 1135 1136 |
# File 'lib/aws-sdk-drs/types.rb', line 1131 class Disk < Struct.new( :bytes, :device_name) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
The disk or device name.
1131 1132 1133 1134 1135 1136 |
# File 'lib/aws-sdk-drs/types.rb', line 1131 class Disk < Struct.new( :bytes, :device_name) SENSITIVE = [] include Aws::Structure end |