Class: Aws::Drs::Types::EventResourceData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::EventResourceData
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
EventResourceData is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EventResourceData corresponding to the set member.
Properties of resource related to a job event.
Direct Known Subclasses
Defined Under Namespace
Classes: SourceNetworkData, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_network_data ⇒ Types::SourceNetworkData
Source Network properties.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#source_network_data ⇒ Types::SourceNetworkData
Source Network properties.
1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 |
# File 'lib/aws-sdk-drs/types.rb', line 1099 class EventResourceData < Struct.new( :source_network_data, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SourceNetworkData < EventResourceData; end class Unknown < EventResourceData; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1099 1100 1101 |
# File 'lib/aws-sdk-drs/types.rb', line 1099 def unknown @unknown end |