Class: Aws::Drs::Types::GetFailbackReplicationConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidth_throttlingInteger

Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.

Returns:

  • (Integer)


1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-drs/types.rb', line 1229

class GetFailbackReplicationConfigurationResponse < Struct.new(
  :recovery_instance_id,
  :name,
  :bandwidth_throttling,
  :use_private_ip,
  :internet_protocol)
  SENSITIVE = []
  include Aws::Structure
end

#internet_protocolString

Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6)

Returns:

  • (String)


1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-drs/types.rb', line 1229

class GetFailbackReplicationConfigurationResponse < Struct.new(
  :recovery_instance_id,
  :name,
  :bandwidth_throttling,
  :use_private_ip,
  :internet_protocol)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Failback Replication Configuration.

Returns:

  • (String)


1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-drs/types.rb', line 1229

class GetFailbackReplicationConfigurationResponse < Struct.new(
  :recovery_instance_id,
  :name,
  :bandwidth_throttling,
  :use_private_ip,
  :internet_protocol)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_instance_idString

The ID of the Recovery Instance.

Returns:

  • (String)


1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-drs/types.rb', line 1229

class GetFailbackReplicationConfigurationResponse < Struct.new(
  :recovery_instance_id,
  :name,
  :bandwidth_throttling,
  :use_private_ip,
  :internet_protocol)
  SENSITIVE = []
  include Aws::Structure
end

#use_private_ipBoolean

Whether to use Private IP for the failback replication of the Recovery Instance.

Returns:

  • (Boolean)


1229
1230
1231
1232
1233
1234
1235
1236
1237
# File 'lib/aws-sdk-drs/types.rb', line 1229

class GetFailbackReplicationConfigurationResponse < Struct.new(
  :recovery_instance_id,
  :name,
  :bandwidth_throttling,
  :use_private_ip,
  :internet_protocol)
  SENSITIVE = []
  include Aws::Structure
end