Class: Aws::Drs::Types::GetLaunchConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::GetLaunchConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
Instance Attribute Details
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
1246 1247 1248 1249 1250 |
# File 'lib/aws-sdk-drs/types.rb', line 1246 class GetLaunchConfigurationRequest < Struct.new( :source_server_id) SENSITIVE = [] include Aws::Structure end |