Class: Aws::Drs::Types::InternalServerException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::InternalServerException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
The request processing has failed because of an unknown error, exception or failure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#retry_after_seconds ⇒ Integer
The number of seconds after which the request should be safe to retry.
Instance Attribute Details
#message ⇒ String
948 949 950 951 952 953 |
# File 'lib/aws-sdk-drs/types.rb', line 948 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds after which the request should be safe to retry.
948 949 950 951 952 953 |
# File 'lib/aws-sdk-drs/types.rb', line 948 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |