Class: Aws::Drs::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

A job is an asynchronous workflow.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN of a Job.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#creation_date_time ⇒ String

The date and time of when the Job was created.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#end_date_time ⇒ String

The date and time of when the Job ended.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#initiated_by ⇒ String

A string representing who initiated the Job.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#job_id ⇒ String

The ID of the Job.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#participating_resources ⇒ Array<Types::ParticipatingResource>

A list of resources that the Job is acting upon.

Returns:



1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#participating_servers ⇒ Array<Types::ParticipatingServer>

A list of servers that the Job is acting upon.

Returns:



1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#status ⇒ String

The status of the Job.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A list of tags associated with the Job.

Returns:

  • (Hash<String,String>)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#type ⇒ String

The type of the Job.

Returns:

  • (String)


1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/aws-sdk-drs/types.rb', line 1687

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end