Class: Aws::Drs::Types::JobLogEventData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::JobLogEventData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Metadata associated with a Job log.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt_count ⇒ Integer
Retries for this operation.
-
#conversion_properties ⇒ Types::ConversionProperties
Properties of a conversion job.
-
#conversion_server_id ⇒ String
The ID of a conversion server.
-
#event_resource_data ⇒ Types::EventResourceData
Properties of resource related to a job event.
-
#max_attempts_count ⇒ Integer
The maximum number of retries that will be attempted if this operation failed.
-
#raw_error ⇒ String
A string representing a job error.
-
#source_server_id ⇒ String
The ID of a Source Server.
-
#target_instance_id ⇒ String
The ID of a Recovery Instance.
Instance Attribute Details
#attempt_count ⇒ Integer
Retries for this operation.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#conversion_properties ⇒ Types::ConversionProperties
Properties of a conversion job
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#conversion_server_id ⇒ String
The ID of a conversion server.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#event_resource_data ⇒ Types::EventResourceData
Properties of resource related to a job event.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#max_attempts_count ⇒ Integer
The maximum number of retries that will be attempted if this operation failed.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#raw_error ⇒ String
A string representing a job error.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
The ID of a Source Server.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |
#target_instance_id ⇒ String
The ID of a Recovery Instance.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/aws-sdk-drs/types.rb', line 1443 class JobLogEventData < Struct.new( :source_server_id, :conversion_server_id, :target_instance_id, :raw_error, :conversion_properties, :event_resource_data, :attempt_count, :max_attempts_count) SENSITIVE = [] include Aws::Structure end |