Class: Aws::Drs::Types::LaunchActionsStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LaunchActionsStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Launch actions status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#runs ⇒ Array<Types::LaunchActionRun>
List of post launch action status.
-
#ssm_agent_discovery_datetime ⇒ String
Time where the AWS Systems Manager was detected as running on the launched instance.
Instance Attribute Details
#runs ⇒ Array<Types::LaunchActionRun>
List of post launch action status.
1601 1602 1603 1604 1605 1606 |
# File 'lib/aws-sdk-drs/types.rb', line 1601 class LaunchActionsStatus < Struct.new( :ssm_agent_discovery_datetime, :runs) SENSITIVE = [] include Aws::Structure end |
#ssm_agent_discovery_datetime ⇒ String
Time where the AWS Systems Manager was detected as running on the launched instance.
1601 1602 1603 1604 1605 1606 |
# File 'lib/aws-sdk-drs/types.rb', line 1601 class LaunchActionsStatus < Struct.new( :ssm_agent_discovery_datetime, :runs) SENSITIVE = [] include Aws::Structure end |