Class: Aws::Drs::Types::LaunchConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_private_ipBoolean

Whether we should copy the Private IP of the Source Server to the Recovery Instance.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#copy_tagsBoolean

Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_launch_template_idString

The EC2 launch template ID of this launch configuration.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#launch_dispositionString

The state of the Recovery Instance in EC2 after the recovery operation.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#launch_into_instance_propertiesTypes::LaunchIntoInstanceProperties

Launch into existing instance properties.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#licensingTypes::Licensing

The licensing configuration to be used for this launch configuration.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the launch configuration.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#post_launch_enabledBoolean

Whether we want to activate post-launch actions for the Source Server.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server for this launch configuration.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#target_instance_type_right_sizing_methodString

Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/aws-sdk-drs/types.rb', line 1629

class LaunchConfiguration < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :ec2_launch_template_id,
  :launch_disposition,
  :launch_into_instance_properties,
  :licensing,
  :name,
  :post_launch_enabled,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end