Class: Aws::Drs::Types::LaunchConfigurationTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Account level Launch Configuration Template.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN of the Launch Configuration Template.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#copy_private_ipBoolean

Copy private IP.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#copy_tagsBoolean

Copy tags.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#export_bucket_arnString

S3 bucket ARN to export Source Network templates.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#launch_configuration_template_idString

ID of the Launch Configuration Template.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#launch_dispositionString

Launch disposition.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#launch_into_source_instanceBoolean

DRS will set the ‘launch into instance ID’ of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#licensingTypes::Licensing

Licensing.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#post_launch_enabledBoolean

Post-launch actions activated.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

Tags of the Launch Configuration Template.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#target_instance_type_right_sizing_methodString

Target instance type right-sizing method.



1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/aws-sdk-drs/types.rb', line 1694

class LaunchConfigurationTemplate < Struct.new(
  :arn,
  :copy_private_ip,
  :copy_tags,
  :export_bucket_arn,
  :launch_configuration_template_id,
  :launch_disposition,
  :launch_into_source_instance,
  :licensing,
  :post_launch_enabled,
  :tags,
  :target_instance_type_right_sizing_method)
  SENSITIVE = [:tags]
  include Aws::Structure
end