Class: Aws::Drs::Types::LifeCycleLastLaunch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

An object containing information regarding the last launch of a Source Server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#initiatedTypes::LifeCycleLastLaunchInitiated

An object containing information regarding the initiation of the last launch of a Source Server.



1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-drs/types.rb', line 1341

class LifeCycleLastLaunch < Struct.new(
  :initiated,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Status of Source Server’s last launch.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-drs/types.rb', line 1341

class LifeCycleLastLaunch < Struct.new(
  :initiated,
  :status)
  SENSITIVE = []
  include Aws::Structure
end