Class: Aws::Drs::Types::PITPolicyRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass PITPolicyRule data as a hash:

{
  enabled: false,
  interval: 1, # required
  retention_duration: 1, # required
  rule_id: 1,
  units: "MINUTE", # required, accepts MINUTE, HOUR, DAY
}

A rule in the Point in Time (PIT) policy representing when to take snapshots and how long to retain them for.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Whether this rule is enabled or not.

Returns:

  • (Boolean)


1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/aws-sdk-drs/types.rb', line 1613

class PITPolicyRule < Struct.new(
  :enabled,
  :interval,
  :retention_duration,
  :rule_id,
  :units)
  SENSITIVE = []
  include Aws::Structure
end

#intervalInteger

How often, in the chosen units, a snapshot should be taken.

Returns:

  • (Integer)


1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/aws-sdk-drs/types.rb', line 1613

class PITPolicyRule < Struct.new(
  :enabled,
  :interval,
  :retention_duration,
  :rule_id,
  :units)
  SENSITIVE = []
  include Aws::Structure
end

#retention_durationInteger

The duration to retain a snapshot for, in the chosen units.

Returns:

  • (Integer)


1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/aws-sdk-drs/types.rb', line 1613

class PITPolicyRule < Struct.new(
  :enabled,
  :interval,
  :retention_duration,
  :rule_id,
  :units)
  SENSITIVE = []
  include Aws::Structure
end

#rule_idInteger

The ID of the rule.

Returns:

  • (Integer)


1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/aws-sdk-drs/types.rb', line 1613

class PITPolicyRule < Struct.new(
  :enabled,
  :interval,
  :retention_duration,
  :rule_id,
  :units)
  SENSITIVE = []
  include Aws::Structure
end

#unitsString

The units used to measure the interval and retentionDuration.

Returns:

  • (String)


1613
1614
1615
1616
1617
1618
1619
1620
1621
# File 'lib/aws-sdk-drs/types.rb', line 1613

class PITPolicyRule < Struct.new(
  :enabled,
  :interval,
  :retention_duration,
  :rule_id,
  :units)
  SENSITIVE = []
  include Aws::Structure
end