Class: Aws::Drs::Types::PutLaunchActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::PutLaunchActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_code ⇒ String
Launch action code.
-
#action_id ⇒ String
Launch action Id.
-
#action_version ⇒ String
Launch action version.
-
#active ⇒ Boolean
Whether the launch action is active.
-
#category ⇒ String
Launch action category.
-
#description ⇒ String
Launch action description.
-
#name ⇒ String
Launch action name.
-
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
-
#order ⇒ Integer
Launch action order.
-
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
-
#resource_id ⇒ String
Launch configuration template Id or Source Server Id.
Instance Attribute Details
#action_code ⇒ String
Launch action code.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#action_id ⇒ String
Launch action Id.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#action_version ⇒ String
Launch action version.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#active ⇒ Boolean
Whether the launch action is active.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Launch action category.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Launch action description.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Launch action name.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#order ⇒ Integer
Launch action order.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Launch configuration template Id or Source Server Id
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-drs/types.rb', line 2139 class PutLaunchActionRequest < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id) SENSITIVE = [] include Aws::Structure end |