Class: Aws::Drs::Types::PutLaunchActionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::PutLaunchActionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_code ⇒ String
Launch action code.
-
#action_id ⇒ String
Launch action Id.
-
#action_version ⇒ String
Launch action version.
-
#active ⇒ Boolean
Whether the launch action is active.
-
#category ⇒ String
Launch action category.
-
#description ⇒ String
Launch action description.
-
#name ⇒ String
Launch action name.
-
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
-
#order ⇒ Integer
Launch action order.
-
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
-
#resource_id ⇒ String
Launch configuration template Id or Source Server Id.
-
#type ⇒ String
Launch action type.
Instance Attribute Details
#action_code ⇒ String
Launch action code.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#action_id ⇒ String
Launch action Id.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#action_version ⇒ String
Launch action version.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#active ⇒ Boolean
Whether the launch action is active.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Launch action category.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Launch action description.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Launch action name.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#order ⇒ Integer
Launch action order.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Launch configuration template Id or Source Server Id
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Launch action type.
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-drs/types.rb', line 2279 class PutLaunchActionResponse < Struct.new( :resource_id, :action_id, :action_code, :type, :name, :active, :order, :action_version, :optional, :parameters, :description, :category) SENSITIVE = [] include Aws::Structure end |