Class: Aws::Drs::Types::RecoveryInstanceDataReplicationInfoReplicatedDisk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryInstanceDataReplicationInfoReplicatedDisk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
A disk that should be replicated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backlogged_storage_bytes ⇒ Integer
The size of the replication backlog in bytes.
-
#device_name ⇒ String
The name of the device.
-
#replicated_storage_bytes ⇒ Integer
The amount of data replicated so far in bytes.
-
#rescanned_storage_bytes ⇒ Integer
The amount of data to be rescanned in bytes.
-
#total_storage_bytes ⇒ Integer
The total amount of data to be replicated in bytes.
Instance Attribute Details
#backlogged_storage_bytes ⇒ Integer
The size of the replication backlog in bytes.
2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-drs/types.rb', line 2466 class RecoveryInstanceDataReplicationInfoReplicatedDisk < Struct.new( :device_name, :total_storage_bytes, :replicated_storage_bytes, :rescanned_storage_bytes, :backlogged_storage_bytes) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
The name of the device.
2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-drs/types.rb', line 2466 class RecoveryInstanceDataReplicationInfoReplicatedDisk < Struct.new( :device_name, :total_storage_bytes, :replicated_storage_bytes, :rescanned_storage_bytes, :backlogged_storage_bytes) SENSITIVE = [] include Aws::Structure end |
#replicated_storage_bytes ⇒ Integer
The amount of data replicated so far in bytes.
2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-drs/types.rb', line 2466 class RecoveryInstanceDataReplicationInfoReplicatedDisk < Struct.new( :device_name, :total_storage_bytes, :replicated_storage_bytes, :rescanned_storage_bytes, :backlogged_storage_bytes) SENSITIVE = [] include Aws::Structure end |
#rescanned_storage_bytes ⇒ Integer
The amount of data to be rescanned in bytes.
2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-drs/types.rb', line 2466 class RecoveryInstanceDataReplicationInfoReplicatedDisk < Struct.new( :device_name, :total_storage_bytes, :replicated_storage_bytes, :rescanned_storage_bytes, :backlogged_storage_bytes) SENSITIVE = [] include Aws::Structure end |
#total_storage_bytes ⇒ Integer
The total amount of data to be replicated in bytes.
2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-drs/types.rb', line 2466 class RecoveryInstanceDataReplicationInfoReplicatedDisk < Struct.new( :device_name, :total_storage_bytes, :replicated_storage_bytes, :rescanned_storage_bytes, :backlogged_storage_bytes) SENSITIVE = [] include Aws::Structure end |