Class: Aws::Drs::Types::RecoveryPlan
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryPlan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
A Recovery Plan resource.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#created_at ⇒ String
The timestamp when the Recovery Plan was created.
-
#description ⇒ String
The description of a Recovery Plan.
-
#name ⇒ String
The name of a Recovery Plan.
-
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan.
-
#status ⇒ String
The status of the Recovery Plan.
-
#tags ⇒ Hash<String,String>
The tags associated with the Recovery Plan.
-
#updated_at ⇒ String
The timestamp when the Recovery Plan was last updated.
Instance Attribute Details
#created_at ⇒ String
The timestamp when the Recovery Plan was created.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#description ⇒ String
The description of a Recovery Plan.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#name ⇒ String
The name of a Recovery Plan.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#status ⇒ String
The status of the Recovery Plan.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the Recovery Plan.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#updated_at ⇒ String
The timestamp when the Recovery Plan was last updated.
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/aws-sdk-drs/types.rb', line 3214 class RecoveryPlan < Struct.new( :recovery_plan_arn, :name, :description, :status, :created_at, :updated_at, :tags) SENSITIVE = [:tags] include Aws::Structure end |