Class: Aws::Drs::Types::RecoveryPlanExecutionStepConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryPlanExecutionStepConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
RecoveryPlanExecutionStepConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RecoveryPlanExecutionStepConfiguration corresponding to the set member.
Type-specific configuration for an execution step response. Mirrors RecoveryPlanStepConfiguration but uses execution-enriched server shapes.
Defined Under Namespace
Classes: ExecutionServerStepConfiguration, Unknown, WaitStepConfiguration
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_server_step_configuration ⇒ Types::ExecutionServerStepConfiguration
Configuration for a SERVER type step (with execution state like jobID).
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#wait_step_configuration ⇒ Types::WaitStepConfiguration
Configuration for a WAIT type step.
Instance Attribute Details
#execution_server_step_configuration ⇒ Types::ExecutionServerStepConfiguration
Configuration for a SERVER type step (with execution state like jobID).
3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 |
# File 'lib/aws-sdk-drs/types.rb', line 3393 class RecoveryPlanExecutionStepConfiguration < Struct.new( :execution_server_step_configuration, :wait_step_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExecutionServerStepConfiguration < RecoveryPlanExecutionStepConfiguration; end class WaitStepConfiguration < RecoveryPlanExecutionStepConfiguration; end class Unknown < RecoveryPlanExecutionStepConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3393 3394 3395 |
# File 'lib/aws-sdk-drs/types.rb', line 3393 def unknown @unknown end |
#wait_step_configuration ⇒ Types::WaitStepConfiguration
Configuration for a WAIT type step.
3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 |
# File 'lib/aws-sdk-drs/types.rb', line 3393 class RecoveryPlanExecutionStepConfiguration < Struct.new( :execution_server_step_configuration, :wait_step_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExecutionServerStepConfiguration < RecoveryPlanExecutionStepConfiguration; end class WaitStepConfiguration < RecoveryPlanExecutionStepConfiguration; end class Unknown < RecoveryPlanExecutionStepConfiguration; end end |