Class: Aws::Drs::Types::RecoveryPlanExecutionStepSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryPlanExecutionStepSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Summary information about a Recovery Plan execution step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::RecoveryPlanExecutionStepConfiguration
Type-specific configuration for an execution step response.
-
#error_detail ⇒ Types::ErrorDetail
Error details if the step failed.
-
#recovery_plan_execution_step_arn ⇒ String
The ARN of the execution step.
-
#status ⇒ String
The status of the execution step.
-
#step_index ⇒ Integer
The order of a step within a Recovery Plan (1-based).
-
#step_name ⇒ String
The name of a Recovery Plan Step.
Instance Attribute Details
#configuration ⇒ Types::RecoveryPlanExecutionStepConfiguration
Type-specific configuration for an execution step response. Mirrors RecoveryPlanStepConfiguration but uses execution-enriched server shapes.
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |
#error_detail ⇒ Types::ErrorDetail
Error details if the step failed.
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |
#recovery_plan_execution_step_arn ⇒ String
The ARN of the execution step.
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the execution step.
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |
#step_index ⇒ Integer
The order of a step within a Recovery Plan (1-based).
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |
#step_name ⇒ String
The name of a Recovery Plan Step.
3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-drs/types.rb', line 3436 class RecoveryPlanExecutionStepSummary < Struct.new( :recovery_plan_execution_step_arn, :step_name, :step_index, :status, :configuration, :error_detail) SENSITIVE = [] include Aws::Structure end |