Class: Aws::Drs::Types::RecoveryPlanSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryPlanSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Summary information about a Recovery Plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ String
The timestamp when the Recovery Plan was created.
-
#name ⇒ String
The name of a Recovery Plan.
-
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan.
-
#status ⇒ String
The status of the Recovery Plan.
-
#updated_at ⇒ String
The timestamp when the Recovery Plan was last updated.
Instance Attribute Details
#created_at ⇒ String
The timestamp when the Recovery Plan was created.
3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-drs/types.rb', line 3599 class RecoveryPlanSummary < Struct.new( :recovery_plan_arn, :name, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of a Recovery Plan.
3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-drs/types.rb', line 3599 class RecoveryPlanSummary < Struct.new( :recovery_plan_arn, :name, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan.
3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-drs/types.rb', line 3599 class RecoveryPlanSummary < Struct.new( :recovery_plan_arn, :name, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Recovery Plan.
3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-drs/types.rb', line 3599 class RecoveryPlanSummary < Struct.new( :recovery_plan_arn, :name, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ String
The timestamp when the Recovery Plan was last updated.
3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/aws-sdk-drs/types.rb', line 3599 class RecoveryPlanSummary < Struct.new( :recovery_plan_arn, :name, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |