Class: Aws::Drs::Types::RecoverySnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

A snapshot of a Source Server used during recovery.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ebs_snapshots ⇒ Array<String>

A list of EBS snapshots.

Returns:

  • (Array<String>)


3633
3634
3635
3636
3637
3638
3639
3640
3641
# File 'lib/aws-sdk-drs/types.rb', line 3633

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#expected_timestamp ⇒ String

The timestamp of when we expect the snapshot to be taken.

Returns:

  • (String)


3633
3634
3635
3636
3637
3638
3639
3640
3641
# File 'lib/aws-sdk-drs/types.rb', line 3633

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_id ⇒ String

The ID of the Recovery Snapshot.

Returns:

  • (String)


3633
3634
3635
3636
3637
3638
3639
3640
3641
# File 'lib/aws-sdk-drs/types.rb', line 3633

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_id ⇒ String

The ID of the Source Server that the snapshot was taken for.

Returns:

  • (String)


3633
3634
3635
3636
3637
3638
3639
3640
3641
# File 'lib/aws-sdk-drs/types.rb', line 3633

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp ⇒ String

The actual timestamp that the snapshot was taken.

Returns:

  • (String)


3633
3634
3635
3636
3637
3638
3639
3640
3641
# File 'lib/aws-sdk-drs/types.rb', line 3633

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end