Class: Aws::Drs::Types::ReplicationConfigurationReplicatedDisk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ReplicationConfigurationReplicatedDisk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
When making an API call, you may pass ReplicationConfigurationReplicatedDisk data as a hash:
{
device_name: "BoundedString",
iops: 1,
is_boot_disk: false,
optimized_staging_disk_type: "AUTO", # accepts AUTO, GP2, GP3, IO1, SC1, ST1, STANDARD
staging_disk_type: "AUTO", # accepts AUTO, GP2, GP3, IO1, SC1, ST1, STANDARD
throughput: 1,
}
The configuration of a disk of the Source Server to be replicated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_name ⇒ String
The name of the device.
-
#iops ⇒ Integer
The requested number of I/O operations per second (IOPS).
-
#is_boot_disk ⇒ Boolean
Whether to boot from this disk or not.
-
#optimized_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication when `stagingDiskType` is set to Auto.
-
#staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
-
#throughput ⇒ Integer
The throughput to use for the EBS volume in MiB/s.
Instance Attribute Details
#device_name ⇒ String
The name of the device.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The requested number of I/O operations per second (IOPS).
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#is_boot_disk ⇒ Boolean
Whether to boot from this disk or not.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#optimized_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication when `stagingDiskType` is set to Auto. This is a read-only field.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
The throughput to use for the EBS volume in MiB/s. This parameter is valid only for gp3 volumes.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-drs/types.rb', line 2152 class ReplicationConfigurationReplicatedDisk < Struct.new( :device_name, :iops, :is_boot_disk, :optimized_staging_disk_type, :staging_disk_type, :throughput) SENSITIVE = [] include Aws::Structure end |