Class: Aws::Drs::Types::ServerStepConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ServerStepConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Configuration for a SERVER type step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#servers ⇒ Array<Types::RecoveryPlanServer>
The list of servers to recover in this step.
Instance Attribute Details
#servers ⇒ Array<Types::RecoveryPlanServer>
The list of servers to recover in this step.
4022 4023 4024 4025 4026 |
# File 'lib/aws-sdk-drs/types.rb', line 4022 class ServerStepConfiguration < Struct.new( :servers) SENSITIVE = [] include Aws::Structure end |