Class: Aws::Drs::Types::SourceNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

The ARN of the Source Network.

Constant Summary collapse

SENSITIVE =
[:tags, :replication_status_details, :cfn_stack_name]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Source Network.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#cfn_stack_nameString

CloudFormation stack name that was deployed for recovering the Source Network.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#last_recoveryTypes::RecoveryLifeCycle

An object containing information regarding the last recovery of the Source Network.



3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#launched_vpc_idString

ID of the recovered VPC following Source Network recovery.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#replication_statusString

Status of Source Network Replication. Possible values: (a) STOPPED - Source Network is not replicating. (b) IN_PROGRESS - Source Network is being replicated. © PROTECTED - Source Network was replicated successfully and is being synchronized for changes. (d) ERROR - Source Network replication has failed

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#replication_status_detailsString

Error details in case Source Network replication status is ERROR.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#source_account_idString

Account ID containing the VPC protected by the Source Network.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#source_network_idString

Source Network ID.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#source_regionString

Region containing the VPC protected by the Source Network.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#source_vpc_idString

VPC ID protected by the Source Network.

Returns:

  • (String)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end

#tagsHash<String,String>

A list of tags associated with the Source Network.

Returns:

  • (Hash<String,String>)


3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
# File 'lib/aws-sdk-drs/types.rb', line 3151

class SourceNetwork < Struct.new(
  :source_network_id,
  :source_vpc_id,
  :arn,
  :tags,
  :replication_status,
  :replication_status_details,
  :cfn_stack_name,
  :source_region,
  :source_account_id,
  :last_recovery,
  :launched_vpc_id)
  SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name]
  include Aws::Structure
end