Class: Aws::Drs::Types::SourceNetworkData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::SourceNetworkData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Properties of Source Network related to a job event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_network_id ⇒ String
Source Network ID.
-
#source_vpc ⇒ String
VPC ID protected by the Source Network.
-
#stack_name ⇒ String
CloudFormation stack name that was deployed for recovering the Source Network.
-
#target_vpc ⇒ String
ID of the recovered VPC following Source Network recovery.
Instance Attribute Details
#source_network_id ⇒ String
Source Network ID.
3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-drs/types.rb', line 3188 class SourceNetworkData < Struct.new( :source_network_id, :source_vpc, :target_vpc, :stack_name) SENSITIVE = [] include Aws::Structure end |
#source_vpc ⇒ String
VPC ID protected by the Source Network.
3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-drs/types.rb', line 3188 class SourceNetworkData < Struct.new( :source_network_id, :source_vpc, :target_vpc, :stack_name) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
CloudFormation stack name that was deployed for recovering the Source Network.
3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-drs/types.rb', line 3188 class SourceNetworkData < Struct.new( :source_network_id, :source_vpc, :target_vpc, :stack_name) SENSITIVE = [] include Aws::Structure end |
#target_vpc ⇒ String
ID of the recovered VPC following Source Network recovery.
3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-drs/types.rb', line 3188 class SourceNetworkData < Struct.new( :source_network_id, :source_vpc, :target_vpc, :stack_name) SENSITIVE = [] include Aws::Structure end |