Class: Aws::Drs::Types::SourceProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::SourceProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Properties of the Source Server machine.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpus ⇒ Array<Types::CPU>
An array of CPUs.
-
#disks ⇒ Array<Types::Disk>
An array of disks.
-
#identification_hints ⇒ Types::IdentificationHints
Hints used to uniquely identify a machine.
-
#last_updated_date_time ⇒ String
The date and time the Source Properties were last updated on.
-
#network_interfaces ⇒ Array<Types::NetworkInterface>
An array of network interfaces.
-
#os ⇒ Types::OS
Operating system.
-
#ram_bytes ⇒ Integer
The amount of RAM in bytes.
-
#recommended_instance_type ⇒ String
The recommended EC2 instance type that will be used when recovering the Source Server.
-
#supports_nitro_instances ⇒ Boolean
Are EC2 nitro instance types supported when recovering the Source Server.
Instance Attribute Details
#cpus ⇒ Array<Types::CPU>
An array of CPUs.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#disks ⇒ Array<Types::Disk>
An array of disks.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#identification_hints ⇒ Types::IdentificationHints
Hints used to uniquely identify a machine.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#last_updated_date_time ⇒ String
The date and time the Source Properties were last updated on.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::NetworkInterface>
An array of network interfaces.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#os ⇒ Types::OS
Operating system.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#ram_bytes ⇒ Integer
The amount of RAM in bytes.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#recommended_instance_type ⇒ String
The recommended EC2 instance type that will be used when recovering the Source Server.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |
#supports_nitro_instances ⇒ Boolean
Are EC2 nitro instance types supported when recovering the Source Server.
4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 |
# File 'lib/aws-sdk-drs/types.rb', line 4238 class SourceProperties < Struct.new( :last_updated_date_time, :recommended_instance_type, :identification_hints, :network_interfaces, :disks, :cpus, :ram_bytes, :os, :supports_nitro_instances) SENSITIVE = [] include Aws::Structure end |