Class: Aws::Drs::Types::StartFailbackLaunchRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass StartFailbackLaunchRequest data as a hash:

{
  recovery_instance_i_ds: ["RecoveryInstanceID"], # required
  tags: {
    "TagKey" => "TagValue",
  },
}

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#recovery_instance_i_dsArray<String>

The IDs of the Recovery Instance whose failback launch we want to request.

Returns:

  • (Array<String>)


2617
2618
2619
2620
2621
2622
# File 'lib/aws-sdk-drs/types.rb', line 2617

class StartFailbackLaunchRequest < Struct.new(
  :recovery_instance_i_ds,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be associated with the failback launch Job.

Returns:

  • (Hash<String,String>)


2617
2618
2619
2620
2621
2622
# File 'lib/aws-sdk-drs/types.rb', line 2617

class StartFailbackLaunchRequest < Struct.new(
  :recovery_instance_i_ds,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end