Class: Aws::Drs::Types::StartRecoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#is_drillBoolean

Whether this Source Server Recovery operation is a drill or not.

Returns:

  • (Boolean)


3457
3458
3459
3460
3461
3462
3463
# File 'lib/aws-sdk-drs/types.rb', line 3457

class StartRecoveryRequest < Struct.new(
  :source_servers,
  :is_drill,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#source_serversArray<Types::StartRecoveryRequestSourceServer>

The Source Servers that we want to start a Recovery Job for.



3457
3458
3459
3460
3461
3462
3463
# File 'lib/aws-sdk-drs/types.rb', line 3457

class StartRecoveryRequest < Struct.new(
  :source_servers,
  :is_drill,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be associated with the Recovery Job.

Returns:

  • (Hash<String,String>)


3457
3458
3459
3460
3461
3462
3463
# File 'lib/aws-sdk-drs/types.rb', line 3457

class StartRecoveryRequest < Struct.new(
  :source_servers,
  :is_drill,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end