Class: Aws::Drs::Types::StartRecoveryRequestSourceServer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass StartRecoveryRequestSourceServer data as a hash:

{
  recovery_snapshot_id: "RecoverySnapshotID",
  source_server_id: "SourceServerID", # required
}

An object representing the Source Server to recover.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recovery_snapshot_idString

The ID of a Recovery Snapshot we want to recover from. Omit this field to launch from the latest data by taking an on-demand snapshot.

Returns:

  • (String)


2609
2610
2611
2612
2613
2614
# File 'lib/aws-sdk-drs/types.rb', line 2609

class StartRecoveryRequestSourceServer < Struct.new(
  :recovery_snapshot_id,
  :source_server_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server you want to recover.

Returns:

  • (String)


2609
2610
2611
2612
2613
2614
# File 'lib/aws-sdk-drs/types.rb', line 2609

class StartRecoveryRequestSourceServer < Struct.new(
  :recovery_snapshot_id,
  :source_server_id)
  SENSITIVE = []
  include Aws::Structure
end