Class: Aws::Drs::Types::StartReplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartReplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass StartReplicationRequest data as a hash:
{
source_server_id: "SourceServerID", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_server_id ⇒ String
The ID of the Source Server to start replication for.
Instance Attribute Details
#source_server_id ⇒ String
The ID of the Source Server to start replication for.
2728 2729 2730 2731 2732 |
# File 'lib/aws-sdk-drs/types.rb', line 2728 class StartReplicationRequest < Struct.new( :source_server_id) SENSITIVE = [] include Aws::Structure end |