Class: Aws::Drs::Types::StartReplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartReplicationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_server ⇒ Types::SourceServer
The Source Server that this action was targeted on.
Instance Attribute Details
#source_server ⇒ Types::SourceServer
The Source Server that this action was targeted on.
3501 3502 3503 3504 3505 |
# File 'lib/aws-sdk-drs/types.rb', line 3501 class StartReplicationResponse < Struct.new( :source_server) SENSITIVE = [] include Aws::Structure end |