Class: Aws::Drs::Types::StartSourceNetworkRecoveryRequestNetworkEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

An object representing the Source Network to recover.

Constant Summary collapse

SENSITIVE =
[:cfn_stack_name]

Instance Attribute Summary collapse

Instance Attribute Details

#cfn_stack_name ⇒ String

CloudFormation stack name to be used for recovering the network.

Returns:

  • (String)


4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-drs/types.rb', line 4594

class StartSourceNetworkRecoveryRequestNetworkEntry < Struct.new(
  :source_network_id,
  :cfn_stack_name)
  SENSITIVE = [:cfn_stack_name]
  include Aws::Structure
end

#source_network_id ⇒ String

The ID of the Source Network you want to recover.

Returns:

  • (String)


4594
4595
4596
4597
4598
4599
# File 'lib/aws-sdk-drs/types.rb', line 4594

class StartSourceNetworkRecoveryRequestNetworkEntry < Struct.new(
  :source_network_id,
  :cfn_stack_name)
  SENSITIVE = [:cfn_stack_name]
  include Aws::Structure
end