Class: Aws::Drs::Types::StopFailbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StopFailbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass StopFailbackRequest data as a hash:
{
recovery_instance_id: "RecoveryInstanceID", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance we want to stop failback for.
Instance Attribute Details
#recovery_instance_id ⇒ String
The ID of the Recovery Instance we want to stop failback for.
2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-drs/types.rb', line 2634 class StopFailbackRequest < Struct.new( :recovery_instance_id) SENSITIVE = [] include Aws::Structure end |