Class: Aws::Drs::Types::TerminateRecoveryInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::TerminateRecoveryInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass TerminateRecoveryInstancesRequest data as a hash:
{
recovery_instance_i_ds: ["RecoveryInstanceID"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#recovery_instance_i_ds ⇒ Array<String>
The IDs of the Recovery Instances that should be terminated.
Instance Attribute Details
#recovery_instance_i_ds ⇒ Array<String>
The IDs of the Recovery Instances that should be terminated.
2687 2688 2689 2690 2691 |
# File 'lib/aws-sdk-drs/types.rb', line 2687 class TerminateRecoveryInstancesRequest < Struct.new( :recovery_instance_i_ds) SENSITIVE = [] include Aws::Structure end |