Class: Aws::Drs::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
The request was denied due to request throttling.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
Quota code.
-
#retry_after_seconds ⇒ String
The number of seconds after which the request should be safe to retry.
-
#service_code ⇒ String
Service code.
Instance Attribute Details
#message ⇒ String
2874 2875 2876 2877 2878 2879 2880 2881 |
# File 'lib/aws-sdk-drs/types.rb', line 2874 class ThrottlingException < Struct.new( :message, :quota_code, :retry_after_seconds, :service_code) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Quota code.
2874 2875 2876 2877 2878 2879 2880 2881 |
# File 'lib/aws-sdk-drs/types.rb', line 2874 class ThrottlingException < Struct.new( :message, :quota_code, :retry_after_seconds, :service_code) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ String
The number of seconds after which the request should be safe to retry.
2874 2875 2876 2877 2878 2879 2880 2881 |
# File 'lib/aws-sdk-drs/types.rb', line 2874 class ThrottlingException < Struct.new( :message, :quota_code, :retry_after_seconds, :service_code) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Service code.
2874 2875 2876 2877 2878 2879 2880 2881 |
# File 'lib/aws-sdk-drs/types.rb', line 2874 class ThrottlingException < Struct.new( :message, :quota_code, :retry_after_seconds, :service_code) SENSITIVE = [] include Aws::Structure end |