Class: Aws::Drs::Types::UpdateReplicationConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateReplicationConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:staging_area_tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Replication Configuration Template ARN.
-
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration Template.
-
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
-
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
-
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
-
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
-
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
-
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
-
#internet_protocol ⇒ String
Which version of the Internet Protocol to use for replication of data.
-
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
-
#replication_configuration_template_id ⇒ String
The Replication Configuration Template ID.
-
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
-
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
-
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
-
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
-
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
Instance Attribute Details
#arn ⇒ String
The Replication Configuration Template ARN.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration Template.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#internet_protocol ⇒ String
Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6)
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replication_configuration_template_id ⇒ String
The Replication Configuration Template ID.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-drs/types.rb', line 4118 class UpdateReplicationConfigurationTemplateRequest < Struct.new( :replication_configuration_template_id, :arn, :staging_area_subnet_id, :associate_default_security_group, :replication_servers_security_groups_i_ds, :replication_server_instance_type, :use_dedicated_replication_server, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :bandwidth_throttling, :data_plane_routing, :create_public_ip, :staging_area_tags, :pit_policy, :auto_replicate_new_disks, :internet_protocol) SENSITIVE = [:staging_area_tags] include Aws::Structure end |