Class: Aws::Drs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Drs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-drs/client.rb,
sig/client.rbs
Overview
An API client for Drs. To construct a client, you need to configure a :region and :credentials.
client = Aws::Drs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateSourceNetworkStackResponseSuccess, _CancelRecoveryPlanExecutionResponseSuccess, _CreateExtendedSourceServerResponseSuccess, _CreateLaunchConfigurationTemplateResponseSuccess, _CreateRecoveryPlanResponseSuccess, _CreateRecoveryPlanStepResponseSuccess, _CreateReplicationConfigurationTemplateResponseSuccess, _CreateSourceNetworkResponseSuccess, _DeleteJobResponseSuccess, _DeleteLaunchActionResponseSuccess, _DeleteLaunchConfigurationTemplateResponseSuccess, _DeleteRecoveryPlanExecutionResponseSuccess, _DeleteRecoveryPlanResponseSuccess, _DeleteRecoveryPlanStepResponseSuccess, _DeleteReplicationConfigurationTemplateResponseSuccess, _DeleteSourceNetworkResponseSuccess, _DeleteSourceServerResponseSuccess, _DescribeJobLogItemsResponseSuccess, _DescribeJobsResponseSuccess, _DescribeLaunchConfigurationTemplatesResponseSuccess, _DescribeRecoveryInstancesResponseSuccess, _DescribeRecoverySnapshotsResponseSuccess, _DescribeReplicationConfigurationTemplatesResponseSuccess, _DescribeSourceNetworksResponseSuccess, _DescribeSourceServersResponseSuccess, _DisconnectSourceServerResponseSuccess, _ExportSourceNetworkCfnTemplateResponseSuccess, _GetFailbackReplicationConfigurationResponseSuccess, _GetLaunchConfigurationResponseSuccess, _GetRecoveryPlanExecutionResponseSuccess, _GetRecoveryPlanExecutionStepResponseSuccess, _GetRecoveryPlanResponseSuccess, _GetRecoveryPlanStepResponseSuccess, _GetReplicationConfigurationResponseSuccess, _InitializeServiceResponseSuccess, _ListExtensibleSourceServersResponseSuccess, _ListLaunchActionsResponseSuccess, _ListRecoveryPlanExecutionStepsResponseSuccess, _ListRecoveryPlanExecutionsResponseSuccess, _ListRecoveryPlanStepsResponseSuccess, _ListRecoveryPlansResponseSuccess, _ListStagingAccountsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutLaunchActionResponseSuccess, _ReorderRecoveryPlanStepsResponseSuccess, _RetryDataReplicationResponseSuccess, _RetryRecoveryPlanExecutionStepResponseSuccess, _ReverseReplicationResponseSuccess, _StartFailbackLaunchResponseSuccess, _StartRecoveryPlanExecutionResponseSuccess, _StartRecoveryResponseSuccess, _StartReplicationResponseSuccess, _StartSourceNetworkRecoveryResponseSuccess, _StartSourceNetworkReplicationResponseSuccess, _StopReplicationResponseSuccess, _StopSourceNetworkReplicationResponseSuccess, _TerminateRecoveryInstancesResponseSuccess, _UpdateLaunchConfigurationResponseSuccess, _UpdateLaunchConfigurationTemplateResponseSuccess, _UpdateRecoveryPlanExecutionStepResponseSuccess, _UpdateRecoveryPlanResponseSuccess, _UpdateRecoveryPlanStepResponseSuccess, _UpdateReplicationConfigurationResponseSuccess, _UpdateReplicationConfigurationTemplateResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network.
-
#cancel_recovery_plan_execution(params = {}) ⇒ Types::CancelRecoveryPlanExecutionResponse
Cancels an in-progress Recovery Plan execution.
-
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
-
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
-
#create_recovery_plan(params = {}) ⇒ Types::CreateRecoveryPlanResponse
Creates a Recovery Plan to orchestrate multi-server disaster recovery.
-
#create_recovery_plan_step(params = {}) ⇒ Types::CreateRecoveryPlanStepResponse
Creates a step in a Recovery Plan.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
-
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
-
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID.
-
#delete_recovery_plan(params = {}) ⇒ Types::DeleteRecoveryPlanResponse
Deletes a Recovery Plan.
-
#delete_recovery_plan_execution(params = {}) ⇒ Types::DeleteRecoveryPlanExecutionResponse
Deletes a Recovery Plan execution record.
-
#delete_recovery_plan_step(params = {}) ⇒ Types::DeleteRecoveryPlanStepResponse
Deletes a step from a Recovery Plan.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs.
-
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
-
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
-
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
-
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery.
-
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery.
-
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
-
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
-
#get_recovery_plan(params = {}) ⇒ Types::GetRecoveryPlanResponse
Gets a Recovery Plan by ARN.
-
#get_recovery_plan_execution(params = {}) ⇒ Types::GetRecoveryPlanExecutionResponse
Gets the details of a Recovery Plan execution.
-
#get_recovery_plan_execution_step(params = {}) ⇒ Types::GetRecoveryPlanExecutionStepResponse
Gets the details of a step within a Recovery Plan execution.
-
#get_recovery_plan_step(params = {}) ⇒ Types::GetRecoveryPlanStepResponse
Gets a Recovery Plan step by ARN.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
-
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a.
-
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
-
#list_recovery_plan_execution_steps(params = {}) ⇒ Types::ListRecoveryPlanExecutionStepsResponse
Lists all steps within a Recovery Plan execution.
-
#list_recovery_plan_executions(params = {}) ⇒ Types::ListRecoveryPlanExecutionsResponse
Lists executions of Recovery Plans, optionally filtered by plan or status.
-
#list_recovery_plan_steps(params = {}) ⇒ Types::ListRecoveryPlanStepsResponse
Lists all steps in a Recovery Plan.
-
#list_recovery_plans(params = {}) ⇒ Types::ListRecoveryPlansResponse
Lists all Recovery Plans in the account.
-
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
-
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
-
#reorder_recovery_plan_steps(params = {}) ⇒ Types::ReorderRecoveryPlanStepsResponse
Reorders steps in a Recovery Plan.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated.
-
#retry_recovery_plan_execution_step(params = {}) ⇒ Types::RetryRecoveryPlanExecutionStepResponse
Retries a failed
SERVERtype execution step. -
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2.
-
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance.
-
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers.
-
#start_recovery_plan_execution(params = {}) ⇒ Types::StartRecoveryPlanExecutionResponse
Starts executing a Recovery Plan in
DRILLorRECOVERYmode. -
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server.
-
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network.
-
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network.
-
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance.
-
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server.
-
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources.
-
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
-
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
-
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
-
#update_recovery_plan(params = {}) ⇒ Types::UpdateRecoveryPlanResponse
Updates a Recovery Plan's name or description.
-
#update_recovery_plan_execution_step(params = {}) ⇒ Types::UpdateRecoveryPlanExecutionStepResponse
Updates an execution step.
-
#update_recovery_plan_step(params = {}) ⇒ Types::UpdateRecoveryPlanStepResponse
Updates a Recovery Plan step's name or configuration.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-drs/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4571 4572 4573 |
# File 'lib/aws-sdk-drs/client.rb', line 4571 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4574 4575 4576 |
# File 'lib/aws-sdk-drs/client.rb', line 4574 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.
86 |
# File 'sig/client.rbs', line 86
def associate_source_network_stack: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-drs/client.rb', line 4544 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Drs') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-drs' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_recovery_plan_execution(params = {}) ⇒ Types::CancelRecoveryPlanExecutionResponse
Cancels an in-progress Recovery Plan execution. Remaining steps are skipped.
97 |
# File 'sig/client.rbs', line 97
def cancel_recovery_plan_execution: (
|
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
107 |
# File 'sig/client.rbs', line 107
def create_extended_source_server: (
|
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
118 |
# File 'sig/client.rbs', line 118
def create_launch_configuration_template: (
|
#create_recovery_plan(params = {}) ⇒ Types::CreateRecoveryPlanResponse
Creates a Recovery Plan to orchestrate multi-server disaster recovery.
139 |
# File 'sig/client.rbs', line 139
def create_recovery_plan: (
|
#create_recovery_plan_step(params = {}) ⇒ Types::CreateRecoveryPlanStepResponse
Creates a step in a Recovery Plan. A step is either SERVER type
(servers to recover in parallel) or WAIT type (timed pause between
steps).
152 |
# File 'sig/client.rbs', line 152
def create_recovery_plan_step: (
|
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
183 |
# File 'sig/client.rbs', line 183
def create_replication_configuration_template: (
|
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
216 |
# File 'sig/client.rbs', line 216
def create_source_network: (
|
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
228 |
# File 'sig/client.rbs', line 228
def delete_job: (
|
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
237 |
# File 'sig/client.rbs', line 237
def delete_launch_action: (
|
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
247 |
# File 'sig/client.rbs', line 247
def delete_launch_configuration_template: (
|
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
253 |
# File 'sig/client.rbs', line 253
def delete_recovery_instance: (
|
#delete_recovery_plan(params = {}) ⇒ Types::DeleteRecoveryPlanResponse
Deletes a Recovery Plan. Cannot delete a plan that has an execution in
a non-terminal status (CREATED, IN_PROGRESS).
263 |
# File 'sig/client.rbs', line 263
def delete_recovery_plan: (
|
#delete_recovery_plan_execution(params = {}) ⇒ Types::DeleteRecoveryPlanExecutionResponse
Deletes a Recovery Plan execution record. Must be in a terminal status.
273 |
# File 'sig/client.rbs', line 273
def delete_recovery_plan_execution: (
|
#delete_recovery_plan_step(params = {}) ⇒ Types::DeleteRecoveryPlanStepResponse
Deletes a step from a Recovery Plan.
283 |
# File 'sig/client.rbs', line 283
def delete_recovery_plan_step: (
|
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
292 |
# File 'sig/client.rbs', line 292
def delete_replication_configuration_template: (
|
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
301 |
# File 'sig/client.rbs', line 301
def delete_source_network: (
|
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID. The Source Server must be disconnected first.
310 |
# File 'sig/client.rbs', line 310
def delete_source_server: (
|
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
321 |
# File 'sig/client.rbs', line 321
def describe_job_log_items: (
|
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are created by the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
334 |
# File 'sig/client.rbs', line 334
def describe_jobs: (
|
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
351 |
# File 'sig/client.rbs', line 351
def describe_launch_configuration_templates: (
|
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
364 |
# File 'sig/client.rbs', line 364
def describe_recovery_instances: (
|
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
380 |
# File 'sig/client.rbs', line 380
def describe_recovery_snapshots: (
|
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
398 |
# File 'sig/client.rbs', line 398
def describe_replication_configuration_templates: (
|
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
411 |
# File 'sig/client.rbs', line 411
def describe_source_networks: (
|
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
428 |
# File 'sig/client.rbs', line 428
def describe_source_servers: (
|
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
440 |
# File 'sig/client.rbs', line 440
def disconnect_recovery_instance: (
|
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
463 |
# File 'sig/client.rbs', line 463
def disconnect_source_server: (
|
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
473 |
# File 'sig/client.rbs', line 473
def export_source_network_cfn_template: (
|
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
487 |
# File 'sig/client.rbs', line 487
def get_failback_replication_configuration: (
|
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
507 |
# File 'sig/client.rbs', line 507
def get_launch_configuration: (
|
#get_recovery_plan(params = {}) ⇒ Types::GetRecoveryPlanResponse
Gets a Recovery Plan by ARN.
517 |
# File 'sig/client.rbs', line 517
def get_recovery_plan: (
|
#get_recovery_plan_execution(params = {}) ⇒ Types::GetRecoveryPlanExecutionResponse
Gets the details of a Recovery Plan execution.
527 |
# File 'sig/client.rbs', line 527
def get_recovery_plan_execution: (
|
#get_recovery_plan_execution_step(params = {}) ⇒ Types::GetRecoveryPlanExecutionStepResponse
Gets the details of a step within a Recovery Plan execution.
537 |
# File 'sig/client.rbs', line 537
def get_recovery_plan_execution_step: (
|
#get_recovery_plan_step(params = {}) ⇒ Types::GetRecoveryPlanStepResponse
Gets a Recovery Plan step by ARN.
547 |
# File 'sig/client.rbs', line 547
def get_recovery_plan_step: (
|
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
574 |
# File 'sig/client.rbs', line 574
def get_replication_configuration: (
|
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
583 |
# File 'sig/client.rbs', line 583
def initialize_service: (
|
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
593 |
# File 'sig/client.rbs', line 593
def list_extensible_source_servers: (
|
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
606 |
# File 'sig/client.rbs', line 606
def list_launch_actions: (
|
#list_recovery_plan_execution_steps(params = {}) ⇒ Types::ListRecoveryPlanExecutionStepsResponse
Lists all steps within a Recovery Plan execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
622 |
# File 'sig/client.rbs', line 622
def list_recovery_plan_execution_steps: (
|
#list_recovery_plan_executions(params = {}) ⇒ Types::ListRecoveryPlanExecutionsResponse
Lists executions of Recovery Plans, optionally filtered by plan or status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
638 |
# File 'sig/client.rbs', line 638
def list_recovery_plan_executions: (
|
#list_recovery_plan_steps(params = {}) ⇒ Types::ListRecoveryPlanStepsResponse
Lists all steps in a Recovery Plan.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
652 |
# File 'sig/client.rbs', line 652
def list_recovery_plan_steps: (
|
#list_recovery_plans(params = {}) ⇒ Types::ListRecoveryPlansResponse
Lists all Recovery Plans in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
665 |
# File 'sig/client.rbs', line 665
def list_recovery_plans: (
|
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
677 |
# File 'sig/client.rbs', line 677
def list_staging_accounts: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
688 |
# File 'sig/client.rbs', line 688
def list_tags_for_resource: (
|
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
709 |
# File 'sig/client.rbs', line 709
def put_launch_action: (
|
#reorder_recovery_plan_steps(params = {}) ⇒ Types::ReorderRecoveryPlanStepsResponse
Reorders steps in a Recovery Plan. Accepts a complete ordered list of step ARNs.
732 |
# File 'sig/client.rbs', line 732
def reorder_recovery_plan_steps: (
|
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated. Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
756 |
# File 'sig/client.rbs', line 756
def retry_data_replication: (
|
#retry_recovery_plan_execution_step(params = {}) ⇒ Types::RetryRecoveryPlanExecutionStepResponse
Retries a failed SERVER type execution step.
766 |
# File 'sig/client.rbs', line 766
def retry_recovery_plan_execution_step: (
|
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region - starts replication back to origin region. For failback instances on origin region - starts replication to target region to re-protect them.
776 |
# File 'sig/client.rbs', line 776
def reverse_replication: (
|
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
786 |
# File 'sig/client.rbs', line 786
def start_failback_launch: (
|
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
797 |
# File 'sig/client.rbs', line 797
def start_recovery: (
|
#start_recovery_plan_execution(params = {}) ⇒ Types::StartRecoveryPlanExecutionResponse
Starts executing a Recovery Plan in DRILL or RECOVERY mode. A plan
cannot have more than one execution in a non-terminal status at a
time.
814 |
# File 'sig/client.rbs', line 814
def start_recovery_plan_execution: (
|
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
833 |
# File 'sig/client.rbs', line 833
def start_replication: (
|
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network. The VPC will be deployed using a dedicated CloudFormation stack.
843 |
# File 'sig/client.rbs', line 843
def start_source_network_recovery: (
|
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network. This action would make the Source Network protected.
860 |
# File 'sig/client.rbs', line 860
def start_source_network_replication: (
|
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
866 |
# File 'sig/client.rbs', line 866
def stop_failback: (
|
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
876 |
# File 'sig/client.rbs', line 876
def stop_replication: (
|
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network. This action would make the Source Network unprotected.
886 |
# File 'sig/client.rbs', line 886
def stop_source_network_replication: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
892 |
# File 'sig/client.rbs', line 892
def tag_resource: (
|
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
903 |
# File 'sig/client.rbs', line 903
def terminate_recovery_instances: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
909 |
# File 'sig/client.rbs', line 909
def untag_resource: (
|
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
916 |
# File 'sig/client.rbs', line 916
def update_failback_replication_configuration: (
|
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
940 |
# File 'sig/client.rbs', line 940
def update_launch_configuration: (
|
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
963 |
# File 'sig/client.rbs', line 963
def update_launch_configuration_template: (
|
#update_recovery_plan(params = {}) ⇒ Types::UpdateRecoveryPlanResponse
Updates a Recovery Plan's name or description.
984 |
# File 'sig/client.rbs', line 984
def update_recovery_plan: (
|
#update_recovery_plan_execution_step(params = {}) ⇒ Types::UpdateRecoveryPlanExecutionStepResponse
Updates an execution step. Supports two actions: (1) skip a step that
is in NOT_STARTED or FAILED status; (2) update the wait duration
of a WAIT type step that is in NOT_STARTED status.
996 |
# File 'sig/client.rbs', line 996
def update_recovery_plan_execution_step: (
|
#update_recovery_plan_step(params = {}) ⇒ Types::UpdateRecoveryPlanStepResponse
Updates a Recovery Plan step's name or configuration. Step type is immutable.
1014 |
# File 'sig/client.rbs', line 1014
def update_recovery_plan_step: (
|
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
1043 |
# File 'sig/client.rbs', line 1043
def update_replication_configuration: (
|
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
1104 |
# File 'sig/client.rbs', line 1104
def update_replication_configuration_template: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4564 4565 4566 |
# File 'lib/aws-sdk-drs/client.rb', line 4564 def waiter_names [] end |