Class: Aws::Drs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Drs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-drs/client.rb
Overview
An API client for Drs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Drs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network.
-
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
-
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
-
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
-
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs.
-
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
-
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
-
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
-
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery.
-
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery.
-
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
-
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
-
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a.
-
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
-
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
-
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated.
-
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2.
-
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance.
-
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers.
-
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server.
-
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network.
-
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network.
-
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance.
-
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server.
-
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources.
-
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
-
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
-
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
413 414 415 |
# File 'lib/aws-sdk-drs/client.rb', line 413 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3549 3550 3551 |
# File 'lib/aws-sdk-drs/client.rb', line 3549 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3552 3553 3554 |
# File 'lib/aws-sdk-drs/client.rb', line 3552 def errors_module Errors end |
Instance Method Details
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.
481 482 483 484 |
# File 'lib/aws-sdk-drs/client.rb', line 481 def associate_source_network_stack(params = {}, = {}) req = build_request(:associate_source_network_stack, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 |
# File 'lib/aws-sdk-drs/client.rb', line 3527 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-drs' context[:gem_version] = '1.35.0' Seahorse::Client::Request.new(handlers, context) end |
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
581 582 583 584 |
# File 'lib/aws-sdk-drs/client.rb', line 581 def create_extended_source_server(params = {}, = {}) req = build_request(:create_extended_source_server, params) req.send_request() end |
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
659 660 661 662 |
# File 'lib/aws-sdk-drs/client.rb', line 659 def create_launch_configuration_template(params = {}, = {}) req = build_request(:create_launch_configuration_template, params) req.send_request() end |
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
803 804 805 806 |
# File 'lib/aws-sdk-drs/client.rb', line 803 def create_replication_configuration_template(params = {}, = {}) req = build_request(:create_replication_configuration_template, params) req.send_request() end |
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
845 846 847 848 |
# File 'lib/aws-sdk-drs/client.rb', line 845 def create_source_network(params = {}, = {}) req = build_request(:create_source_network, params) req.send_request() end |
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
867 868 869 870 |
# File 'lib/aws-sdk-drs/client.rb', line 867 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
893 894 895 896 |
# File 'lib/aws-sdk-drs/client.rb', line 893 def delete_launch_action(params = {}, = {}) req = build_request(:delete_launch_action, params) req.send_request() end |
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
915 916 917 918 |
# File 'lib/aws-sdk-drs/client.rb', line 915 def delete_launch_configuration_template(params = {}, = {}) req = build_request(:delete_launch_configuration_template, params) req.send_request() end |
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
939 940 941 942 |
# File 'lib/aws-sdk-drs/client.rb', line 939 def delete_recovery_instance(params = {}, = {}) req = build_request(:delete_recovery_instance, params) req.send_request() end |
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
961 962 963 964 |
# File 'lib/aws-sdk-drs/client.rb', line 961 def delete_replication_configuration_template(params = {}, = {}) req = build_request(:delete_replication_configuration_template, params) req.send_request() end |
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
983 984 985 986 |
# File 'lib/aws-sdk-drs/client.rb', line 983 def delete_source_network(params = {}, = {}) req = build_request(:delete_source_network, params) req.send_request() end |
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID. The Source Server must be disconnected first.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-drs/client.rb', line 1006 def delete_source_server(params = {}, = {}) req = build_request(:delete_source_server, params) req.send_request() end |
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1068 1069 1070 1071 |
# File 'lib/aws-sdk-drs/client.rb', line 1068 def describe_job_log_items(params = {}, = {}) req = build_request(:describe_job_log_items, params) req.send_request() end |
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are created by the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1152 1153 1154 1155 |
# File 'lib/aws-sdk-drs/client.rb', line 1152 def describe_jobs(params = {}, = {}) req = build_request(:describe_jobs, params) req.send_request() end |
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1207 1208 1209 1210 |
# File 'lib/aws-sdk-drs/client.rb', line 1207 def describe_launch_configuration_templates(params = {}, = {}) req = build_request(:describe_launch_configuration_templates, params) req.send_request() end |
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1310 1311 1312 1313 |
# File 'lib/aws-sdk-drs/client.rb', line 1310 def describe_recovery_instances(params = {}, = {}) req = build_request(:describe_recovery_instances, params) req.send_request() end |
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1367 1368 1369 1370 |
# File 'lib/aws-sdk-drs/client.rb', line 1367 def describe_recovery_snapshots(params = {}, = {}) req = build_request(:describe_recovery_snapshots, params) req.send_request() end |
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1434 1435 1436 1437 |
# File 'lib/aws-sdk-drs/client.rb', line 1434 def describe_replication_configuration_templates(params = {}, = {}) req = build_request(:describe_replication_configuration_templates, params) req.send_request() end |
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1492 1493 1494 1495 |
# File 'lib/aws-sdk-drs/client.rb', line 1492 def describe_source_networks(params = {}, = {}) req = build_request(:describe_source_networks, params) req.send_request() end |
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1601 1602 1603 1604 |
# File 'lib/aws-sdk-drs/client.rb', line 1601 def describe_source_servers(params = {}, = {}) req = build_request(:describe_source_servers, params) req.send_request() end |
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1635 1636 1637 1638 |
# File 'lib/aws-sdk-drs/client.rb', line 1635 def disconnect_recovery_instance(params = {}, = {}) req = build_request(:disconnect_recovery_instance, params) req.send_request() end |
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1753 1754 1755 1756 |
# File 'lib/aws-sdk-drs/client.rb', line 1753 def disconnect_source_server(params = {}, = {}) req = build_request(:disconnect_source_server, params) req.send_request() end |
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
1782 1783 1784 1785 |
# File 'lib/aws-sdk-drs/client.rb', line 1782 def export_source_network_cfn_template(params = {}, = {}) req = build_request(:export_source_network_cfn_template, params) req.send_request() end |
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
1818 1819 1820 1821 |
# File 'lib/aws-sdk-drs/client.rb', line 1818 def get_failback_replication_configuration(params = {}, = {}) req = build_request(:get_failback_replication_configuration, params) req.send_request() end |
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-drs/client.rb', line 1865 def get_launch_configuration(params = {}, = {}) req = build_request(:get_launch_configuration, params) req.send_request() end |
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
1938 1939 1940 1941 |
# File 'lib/aws-sdk-drs/client.rb', line 1938 def get_replication_configuration(params = {}, = {}) req = build_request(:get_replication_configuration, params) req.send_request() end |
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-drs/client.rb', line 1951 def initialize_service(params = {}, = {}) req = build_request(:initialize_service, params) req.send_request() end |
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1999 2000 2001 2002 |
# File 'lib/aws-sdk-drs/client.rb', line 1999 def list_extensible_source_servers(params = {}, = {}) req = build_request(:list_extensible_source_servers, params) req.send_request() end |
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2059 2060 2061 2062 |
# File 'lib/aws-sdk-drs/client.rb', line 2059 def list_launch_actions(params = {}, = {}) req = build_request(:list_launch_actions, params) req.send_request() end |
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2097 2098 2099 2100 |
# File 'lib/aws-sdk-drs/client.rb', line 2097 def list_staging_accounts(params = {}, = {}) req = build_request(:list_staging_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
2126 2127 2128 2129 |
# File 'lib/aws-sdk-drs/client.rb', line 2126 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
2223 2224 2225 2226 |
# File 'lib/aws-sdk-drs/client.rb', line 2223 def put_launch_action(params = {}, = {}) req = build_request(:put_launch_action, params) req.send_request() end |
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated. Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
2332 2333 2334 2335 |
# File 'lib/aws-sdk-drs/client.rb', line 2332 def retry_data_replication(params = {}, = {}) req = build_request(:retry_data_replication, params) req.send_request() end |
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region - starts replication back to origin region. For failback instances on origin region - starts replication to target region to re-protect them.
2365 2366 2367 2368 |
# File 'lib/aws-sdk-drs/client.rb', line 2365 def reverse_replication(params = {}, = {}) req = build_request(:reverse_replication, params) req.send_request() end |
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
2436 2437 2438 2439 |
# File 'lib/aws-sdk-drs/client.rb', line 2436 def start_failback_launch(params = {}, = {}) req = build_request(:start_failback_launch, params) req.send_request() end |
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
2514 2515 2516 2517 |
# File 'lib/aws-sdk-drs/client.rb', line 2514 def start_recovery(params = {}, = {}) req = build_request(:start_recovery, params) req.send_request() end |
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
2607 2608 2609 2610 |
# File 'lib/aws-sdk-drs/client.rb', line 2607 def start_replication(params = {}, = {}) req = build_request(:start_replication, params) req.send_request() end |
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network. The VPC will be deployed using a dedicated CloudFormation stack.
2686 2687 2688 2689 |
# File 'lib/aws-sdk-drs/client.rb', line 2686 def start_source_network_recovery(params = {}, = {}) req = build_request(:start_source_network_recovery, params) req.send_request() end |
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network. This action would make the Source Network protected.
2728 2729 2730 2731 |
# File 'lib/aws-sdk-drs/client.rb', line 2728 def start_source_network_replication(params = {}, = {}) req = build_request(:start_source_network_replication, params) req.send_request() end |
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
2752 2753 2754 2755 |
# File 'lib/aws-sdk-drs/client.rb', line 2752 def stop_failback(params = {}, = {}) req = build_request(:stop_failback, params) req.send_request() end |
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
2846 2847 2848 2849 |
# File 'lib/aws-sdk-drs/client.rb', line 2846 def stop_replication(params = {}, = {}) req = build_request(:stop_replication, params) req.send_request() end |
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network. This action would make the Source Network unprotected.
2888 2889 2890 2891 |
# File 'lib/aws-sdk-drs/client.rb', line 2888 def stop_source_network_replication(params = {}, = {}) req = build_request(:stop_source_network_replication, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
2920 2921 2922 2923 |
# File 'lib/aws-sdk-drs/client.rb', line 2920 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
2983 2984 2985 2986 |
# File 'lib/aws-sdk-drs/client.rb', line 2983 def terminate_recovery_instances(params = {}, = {}) req = build_request(:terminate_recovery_instances, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
3010 3011 3012 3013 |
# File 'lib/aws-sdk-drs/client.rb', line 3010 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
3047 3048 3049 3050 |
# File 'lib/aws-sdk-drs/client.rb', line 3047 def update_failback_replication_configuration(params = {}, = {}) req = build_request(:update_failback_replication_configuration, params) req.send_request() end |
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
3135 3136 3137 3138 |
# File 'lib/aws-sdk-drs/client.rb', line 3135 def update_launch_configuration(params = {}, = {}) req = build_request(:update_launch_configuration, params) req.send_request() end |
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
3210 3211 3212 3213 |
# File 'lib/aws-sdk-drs/client.rb', line 3210 def update_launch_configuration_template(params = {}, = {}) req = build_request(:update_launch_configuration_template, params) req.send_request() end |
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
3373 3374 3375 3376 |
# File 'lib/aws-sdk-drs/client.rb', line 3373 def update_replication_configuration(params = {}, = {}) req = build_request(:update_replication_configuration, params) req.send_request() end |
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
3518 3519 3520 3521 |
# File 'lib/aws-sdk-drs/client.rb', line 3518 def update_replication_configuration_template(params = {}, = {}) req = build_request(:update_replication_configuration_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3542 3543 3544 |
# File 'lib/aws-sdk-drs/client.rb', line 3542 def waiter_names [] end |