Class: Aws::Drs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Drs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-drs/client.rb
Overview
An API client for Drs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Drs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network.
-
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
-
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
-
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
-
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs.
-
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
-
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
-
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
-
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery.
-
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery.
-
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
-
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
-
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a.
-
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
-
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
-
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated.
-
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2.
-
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance.
-
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers.
-
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server.
-
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network.
-
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network.
-
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance.
-
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server.
-
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources.
-
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
-
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
-
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-drs/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3497 3498 3499 |
# File 'lib/aws-sdk-drs/client.rb', line 3497 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3500 3501 3502 |
# File 'lib/aws-sdk-drs/client.rb', line 3500 def errors_module Errors end |
Instance Method Details
#associate_source_network_stack(params = {}) ⇒ Types::AssociateSourceNetworkStackResponse
Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.
453 454 455 456 |
# File 'lib/aws-sdk-drs/client.rb', line 453 def associate_source_network_stack(params = {}, = {}) req = build_request(:associate_source_network_stack, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'lib/aws-sdk-drs/client.rb', line 3475 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-drs' context[:gem_version] = '1.27.0' Seahorse::Client::Request.new(handlers, context) end |
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
550 551 552 553 |
# File 'lib/aws-sdk-drs/client.rb', line 550 def create_extended_source_server(params = {}, = {}) req = build_request(:create_extended_source_server, params) req.send_request() end |
#create_launch_configuration_template(params = {}) ⇒ Types::CreateLaunchConfigurationTemplateResponse
Creates a new Launch Configuration Template.
628 629 630 631 |
# File 'lib/aws-sdk-drs/client.rb', line 628 def create_launch_configuration_template(params = {}, = {}) req = build_request(:create_launch_configuration_template, params) req.send_request() end |
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
772 773 774 775 |
# File 'lib/aws-sdk-drs/client.rb', line 772 def create_replication_configuration_template(params = {}, = {}) req = build_request(:create_replication_configuration_template, params) req.send_request() end |
#create_source_network(params = {}) ⇒ Types::CreateSourceNetworkResponse
Create a new Source Network resource for a provided VPC ID.
814 815 816 817 |
# File 'lib/aws-sdk-drs/client.rb', line 814 def create_source_network(params = {}, = {}) req = build_request(:create_source_network, params) req.send_request() end |
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
836 837 838 839 |
# File 'lib/aws-sdk-drs/client.rb', line 836 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_launch_action(params = {}) ⇒ Struct
Deletes a resource launch action.
862 863 864 865 |
# File 'lib/aws-sdk-drs/client.rb', line 862 def delete_launch_action(params = {}, = {}) req = build_request(:delete_launch_action, params) req.send_request() end |
#delete_launch_configuration_template(params = {}) ⇒ Struct
Deletes a single Launch Configuration Template by ID.
884 885 886 887 |
# File 'lib/aws-sdk-drs/client.rb', line 884 def delete_launch_configuration_template(params = {}, = {}) req = build_request(:delete_launch_configuration_template, params) req.send_request() end |
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
908 909 910 911 |
# File 'lib/aws-sdk-drs/client.rb', line 908 def delete_recovery_instance(params = {}, = {}) req = build_request(:delete_recovery_instance, params) req.send_request() end |
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
930 931 932 933 |
# File 'lib/aws-sdk-drs/client.rb', line 930 def delete_replication_configuration_template(params = {}, = {}) req = build_request(:delete_replication_configuration_template, params) req.send_request() end |
#delete_source_network(params = {}) ⇒ Struct
Delete Source Network resource.
952 953 954 955 |
# File 'lib/aws-sdk-drs/client.rb', line 952 def delete_source_network(params = {}, = {}) req = build_request(:delete_source_network, params) req.send_request() end |
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID. The Source Server must be disconnected first.
975 976 977 978 |
# File 'lib/aws-sdk-drs/client.rb', line 975 def delete_source_server(params = {}, = {}) req = build_request(:delete_source_server, params) req.send_request() end |
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1033 1034 1035 1036 |
# File 'lib/aws-sdk-drs/client.rb', line 1033 def describe_job_log_items(params = {}, = {}) req = build_request(:describe_job_log_items, params) req.send_request() end |
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are created by the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1117 1118 1119 1120 |
# File 'lib/aws-sdk-drs/client.rb', line 1117 def describe_jobs(params = {}, = {}) req = build_request(:describe_jobs, params) req.send_request() end |
#describe_launch_configuration_templates(params = {}) ⇒ Types::DescribeLaunchConfigurationTemplatesResponse
Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1172 1173 1174 1175 |
# File 'lib/aws-sdk-drs/client.rb', line 1172 def describe_launch_configuration_templates(params = {}, = {}) req = build_request(:describe_launch_configuration_templates, params) req.send_request() end |
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1273 1274 1275 1276 |
# File 'lib/aws-sdk-drs/client.rb', line 1273 def describe_recovery_instances(params = {}, = {}) req = build_request(:describe_recovery_instances, params) req.send_request() end |
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1330 1331 1332 1333 |
# File 'lib/aws-sdk-drs/client.rb', line 1330 def describe_recovery_snapshots(params = {}, = {}) req = build_request(:describe_recovery_snapshots, params) req.send_request() end |
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1397 1398 1399 1400 |
# File 'lib/aws-sdk-drs/client.rb', line 1397 def describe_replication_configuration_templates(params = {}, = {}) req = build_request(:describe_replication_configuration_templates, params) req.send_request() end |
#describe_source_networks(params = {}) ⇒ Types::DescribeSourceNetworksResponse
Lists all Source Networks or multiple Source Networks filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1455 1456 1457 1458 |
# File 'lib/aws-sdk-drs/client.rb', line 1455 def describe_source_networks(params = {}, = {}) req = build_request(:describe_source_networks, params) req.send_request() end |
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1561 1562 1563 1564 |
# File 'lib/aws-sdk-drs/client.rb', line 1561 def describe_source_servers(params = {}, = {}) req = build_request(:describe_source_servers, params) req.send_request() end |
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1595 1596 1597 1598 |
# File 'lib/aws-sdk-drs/client.rb', line 1595 def disconnect_recovery_instance(params = {}, = {}) req = build_request(:disconnect_recovery_instance, params) req.send_request() end |
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1710 1711 1712 1713 |
# File 'lib/aws-sdk-drs/client.rb', line 1710 def disconnect_source_server(params = {}, = {}) req = build_request(:disconnect_source_server, params) req.send_request() end |
#export_source_network_cfn_template(params = {}) ⇒ Types::ExportSourceNetworkCfnTemplateResponse
Export the Source Network CloudFormation template to an S3 bucket.
1739 1740 1741 1742 |
# File 'lib/aws-sdk-drs/client.rb', line 1739 def export_source_network_cfn_template(params = {}, = {}) req = build_request(:export_source_network_cfn_template, params) req.send_request() end |
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
1775 1776 1777 1778 |
# File 'lib/aws-sdk-drs/client.rb', line 1775 def get_failback_replication_configuration(params = {}, = {}) req = build_request(:get_failback_replication_configuration, params) req.send_request() end |
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
1822 1823 1824 1825 |
# File 'lib/aws-sdk-drs/client.rb', line 1822 def get_launch_configuration(params = {}, = {}) req = build_request(:get_launch_configuration, params) req.send_request() end |
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
1895 1896 1897 1898 |
# File 'lib/aws-sdk-drs/client.rb', line 1895 def get_replication_configuration(params = {}, = {}) req = build_request(:get_replication_configuration, params) req.send_request() end |
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
1908 1909 1910 1911 |
# File 'lib/aws-sdk-drs/client.rb', line 1908 def initialize_service(params = {}, = {}) req = build_request(:initialize_service, params) req.send_request() end |
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-drs/client.rb', line 1956 def list_extensible_source_servers(params = {}, = {}) req = build_request(:list_extensible_source_servers, params) req.send_request() end |
#list_launch_actions(params = {}) ⇒ Types::ListLaunchActionsResponse
Lists resource launch actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2016 2017 2018 2019 |
# File 'lib/aws-sdk-drs/client.rb', line 2016 def list_launch_actions(params = {}, = {}) req = build_request(:list_launch_actions, params) req.send_request() end |
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/client.rb', line 2054 def list_staging_accounts(params = {}, = {}) req = build_request(:list_staging_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
2083 2084 2085 2086 |
# File 'lib/aws-sdk-drs/client.rb', line 2083 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_launch_action(params = {}) ⇒ Types::PutLaunchActionResponse
Puts a resource launch action.
2180 2181 2182 2183 |
# File 'lib/aws-sdk-drs/client.rb', line 2180 def put_launch_action(params = {}, = {}) req = build_request(:put_launch_action, params) req.send_request() end |
#retry_data_replication(params = {}) ⇒ Types::SourceServer
WARNING: RetryDataReplication is deprecated. Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
2286 2287 2288 2289 |
# File 'lib/aws-sdk-drs/client.rb', line 2286 def retry_data_replication(params = {}, = {}) req = build_request(:retry_data_replication, params) req.send_request() end |
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region - starts replication back to origin region. For failback instances on origin region - starts replication to target region to re-protect them.
2319 2320 2321 2322 |
# File 'lib/aws-sdk-drs/client.rb', line 2319 def reverse_replication(params = {}, = {}) req = build_request(:reverse_replication, params) req.send_request() end |
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
2390 2391 2392 2393 |
# File 'lib/aws-sdk-drs/client.rb', line 2390 def start_failback_launch(params = {}, = {}) req = build_request(:start_failback_launch, params) req.send_request() end |
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
2468 2469 2470 2471 |
# File 'lib/aws-sdk-drs/client.rb', line 2468 def start_recovery(params = {}, = {}) req = build_request(:start_recovery, params) req.send_request() end |
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
2558 2559 2560 2561 |
# File 'lib/aws-sdk-drs/client.rb', line 2558 def start_replication(params = {}, = {}) req = build_request(:start_replication, params) req.send_request() end |
#start_source_network_recovery(params = {}) ⇒ Types::StartSourceNetworkRecoveryResponse
Deploy VPC for the specified Source Network and modify launch templates to use this network. The VPC will be deployed using a dedicated CloudFormation stack.
2637 2638 2639 2640 |
# File 'lib/aws-sdk-drs/client.rb', line 2637 def start_source_network_recovery(params = {}, = {}) req = build_request(:start_source_network_recovery, params) req.send_request() end |
#start_source_network_replication(params = {}) ⇒ Types::StartSourceNetworkReplicationResponse
Starts replication for a Source Network. This action would make the Source Network protected.
2679 2680 2681 2682 |
# File 'lib/aws-sdk-drs/client.rb', line 2679 def start_source_network_replication(params = {}, = {}) req = build_request(:start_source_network_replication, params) req.send_request() end |
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
2703 2704 2705 2706 |
# File 'lib/aws-sdk-drs/client.rb', line 2703 def stop_failback(params = {}, = {}) req = build_request(:stop_failback, params) req.send_request() end |
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
2794 2795 2796 2797 |
# File 'lib/aws-sdk-drs/client.rb', line 2794 def stop_replication(params = {}, = {}) req = build_request(:stop_replication, params) req.send_request() end |
#stop_source_network_replication(params = {}) ⇒ Types::StopSourceNetworkReplicationResponse
Stops replication for a Source Network. This action would make the Source Network unprotected.
2836 2837 2838 2839 |
# File 'lib/aws-sdk-drs/client.rb', line 2836 def stop_source_network_replication(params = {}, = {}) req = build_request(:stop_source_network_replication, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
2868 2869 2870 2871 |
# File 'lib/aws-sdk-drs/client.rb', line 2868 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
2931 2932 2933 2934 |
# File 'lib/aws-sdk-drs/client.rb', line 2931 def terminate_recovery_instances(params = {}, = {}) req = build_request(:terminate_recovery_instances, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
2958 2959 2960 2961 |
# File 'lib/aws-sdk-drs/client.rb', line 2958 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
2995 2996 2997 2998 |
# File 'lib/aws-sdk-drs/client.rb', line 2995 def update_failback_replication_configuration(params = {}, = {}) req = build_request(:update_failback_replication_configuration, params) req.send_request() end |
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
3083 3084 3085 3086 |
# File 'lib/aws-sdk-drs/client.rb', line 3083 def update_launch_configuration(params = {}, = {}) req = build_request(:update_launch_configuration, params) req.send_request() end |
#update_launch_configuration_template(params = {}) ⇒ Types::UpdateLaunchConfigurationTemplateResponse
Updates an existing Launch Configuration Template by ID.
3158 3159 3160 3161 |
# File 'lib/aws-sdk-drs/client.rb', line 3158 def update_launch_configuration_template(params = {}, = {}) req = build_request(:update_launch_configuration_template, params) req.send_request() end |
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
3321 3322 3323 3324 |
# File 'lib/aws-sdk-drs/client.rb', line 3321 def update_replication_configuration(params = {}, = {}) req = build_request(:update_replication_configuration, params) req.send_request() end |
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
3466 3467 3468 3469 |
# File 'lib/aws-sdk-drs/client.rb', line 3466 def update_replication_configuration_template(params = {}, = {}) req = build_request(:update_replication_configuration_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3490 3491 3492 |
# File 'lib/aws-sdk-drs/client.rb', line 3490 def waiter_names [] end |