Class: Aws::Drs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Drs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-drs/client.rb
Overview
An API client for Drs. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Drs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
-
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
-
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery.
-
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery.
-
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
-
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a.
-
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started.
-
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2.
-
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance.
-
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers.
-
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server.
-
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance.
-
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources.
-
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
-
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-drs/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2515 2516 2517 |
# File 'lib/aws-sdk-drs/client.rb', line 2515 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2518 2519 2520 |
# File 'lib/aws-sdk-drs/client.rb', line 2518 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 |
# File 'lib/aws-sdk-drs/client.rb', line 2493 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-drs' context[:gem_version] = '1.10.0' Seahorse::Client::Request.new(handlers, context) end |
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
458 459 460 461 |
# File 'lib/aws-sdk-drs/client.rb', line 458 def create_extended_source_server(params = {}, = {}) req = build_request(:create_extended_source_server, params) req.send_request() end |
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
595 596 597 598 |
# File 'lib/aws-sdk-drs/client.rb', line 595 def create_replication_configuration_template(params = {}, = {}) req = build_request(:create_replication_configuration_template, params) req.send_request() end |
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
617 618 619 620 |
# File 'lib/aws-sdk-drs/client.rb', line 617 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
641 642 643 644 |
# File 'lib/aws-sdk-drs/client.rb', line 641 def delete_recovery_instance(params = {}, = {}) req = build_request(:delete_recovery_instance, params) req.send_request() end |
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
663 664 665 666 |
# File 'lib/aws-sdk-drs/client.rb', line 663 def delete_replication_configuration_template(params = {}, = {}) req = build_request(:delete_replication_configuration_template, params) req.send_request() end |
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID. The Source Server must be disconnected first.
686 687 688 689 |
# File 'lib/aws-sdk-drs/client.rb', line 686 def delete_source_server(params = {}, = {}) req = build_request(:delete_source_server, params) req.send_request() end |
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
740 741 742 743 |
# File 'lib/aws-sdk-drs/client.rb', line 740 def describe_job_log_items(params = {}, = {}) req = build_request(:describe_job_log_items, params) req.send_request() end |
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are created by the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
803 804 805 806 |
# File 'lib/aws-sdk-drs/client.rb', line 803 def describe_jobs(params = {}, = {}) req = build_request(:describe_jobs, params) req.send_request() end |
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
901 902 903 904 |
# File 'lib/aws-sdk-drs/client.rb', line 901 def describe_recovery_instances(params = {}, = {}) req = build_request(:describe_recovery_instances, params) req.send_request() end |
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
958 959 960 961 |
# File 'lib/aws-sdk-drs/client.rb', line 958 def describe_recovery_snapshots(params = {}, = {}) req = build_request(:describe_recovery_snapshots, params) req.send_request() end |
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1024 1025 1026 1027 |
# File 'lib/aws-sdk-drs/client.rb', line 1024 def describe_replication_configuration_templates(params = {}, = {}) req = build_request(:describe_replication_configuration_templates, params) req.send_request() end |
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1125 1126 1127 1128 |
# File 'lib/aws-sdk-drs/client.rb', line 1125 def describe_source_servers(params = {}, = {}) req = build_request(:describe_source_servers, params) req.send_request() end |
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1159 1160 1161 1162 |
# File 'lib/aws-sdk-drs/client.rb', line 1159 def disconnect_recovery_instance(params = {}, = {}) req = build_request(:disconnect_recovery_instance, params) req.send_request() end |
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1267 1268 1269 1270 |
# File 'lib/aws-sdk-drs/client.rb', line 1267 def disconnect_source_server(params = {}, = {}) req = build_request(:disconnect_source_server, params) req.send_request() end |
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
1303 1304 1305 1306 |
# File 'lib/aws-sdk-drs/client.rb', line 1303 def get_failback_replication_configuration(params = {}, = {}) req = build_request(:get_failback_replication_configuration, params) req.send_request() end |
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
1346 1347 1348 1349 |
# File 'lib/aws-sdk-drs/client.rb', line 1346 def get_launch_configuration(params = {}, = {}) req = build_request(:get_launch_configuration, params) req.send_request() end |
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
1417 1418 1419 1420 |
# File 'lib/aws-sdk-drs/client.rb', line 1417 def get_replication_configuration(params = {}, = {}) req = build_request(:get_replication_configuration, params) req.send_request() end |
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
1430 1431 1432 1433 |
# File 'lib/aws-sdk-drs/client.rb', line 1430 def initialize_service(params = {}, = {}) req = build_request(:initialize_service, params) req.send_request() end |
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1478 1479 1480 1481 |
# File 'lib/aws-sdk-drs/client.rb', line 1478 def list_extensible_source_servers(params = {}, = {}) req = build_request(:list_extensible_source_servers, params) req.send_request() end |
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1516 1517 1518 1519 |
# File 'lib/aws-sdk-drs/client.rb', line 1516 def list_staging_accounts(params = {}, = {}) req = build_request(:list_staging_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
1545 1546 1547 1548 |
# File 'lib/aws-sdk-drs/client.rb', line 1545 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-drs/client.rb', line 1643 def retry_data_replication(params = {}, = {}) req = build_request(:retry_data_replication, params) req.send_request() end |
#reverse_replication(params = {}) ⇒ Types::ReverseReplicationResponse
Start replication to origin / target region - applies only to protected instances that originated in EC2. For recovery instances on target region - starts replication back to origin region. For failback instances on origin region - starts replication to target region to re-protect them.
1676 1677 1678 1679 |
# File 'lib/aws-sdk-drs/client.rb', line 1676 def reverse_replication(params = {}, = {}) req = build_request(:reverse_replication, params) req.send_request() end |
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
1726 1727 1728 1729 |
# File 'lib/aws-sdk-drs/client.rb', line 1726 def start_failback_launch(params = {}, = {}) req = build_request(:start_failback_launch, params) req.send_request() end |
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
1783 1784 1785 1786 |
# File 'lib/aws-sdk-drs/client.rb', line 1783 def start_recovery(params = {}, = {}) req = build_request(:start_recovery, params) req.send_request() end |
#start_replication(params = {}) ⇒ Types::StartReplicationResponse
Starts replication for a stopped Source Server. This action would make the Source Server protected again and restart billing for it.
1868 1869 1870 1871 |
# File 'lib/aws-sdk-drs/client.rb', line 1868 def start_replication(params = {}, = {}) req = build_request(:start_replication, params) req.send_request() end |
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
1892 1893 1894 1895 |
# File 'lib/aws-sdk-drs/client.rb', line 1892 def stop_failback(params = {}, = {}) req = build_request(:stop_failback, params) req.send_request() end |
#stop_replication(params = {}) ⇒ Types::StopReplicationResponse
Stops replication for a Source Server. This action would make the Source Server unprotected, delete its existing snapshots and stop billing for it.
1978 1979 1980 1981 |
# File 'lib/aws-sdk-drs/client.rb', line 1978 def stop_replication(params = {}, = {}) req = build_request(:stop_replication, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
2010 2011 2012 2013 |
# File 'lib/aws-sdk-drs/client.rb', line 2010 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
2052 2053 2054 2055 |
# File 'lib/aws-sdk-drs/client.rb', line 2052 def terminate_recovery_instances(params = {}, = {}) req = build_request(:terminate_recovery_instances, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
2079 2080 2081 2082 |
# File 'lib/aws-sdk-drs/client.rb', line 2079 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
2116 2117 2118 2119 |
# File 'lib/aws-sdk-drs/client.rb', line 2116 def update_failback_replication_configuration(params = {}, = {}) req = build_request(:update_failback_replication_configuration, params) req.send_request() end |
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
2190 2191 2192 2193 |
# File 'lib/aws-sdk-drs/client.rb', line 2190 def update_launch_configuration(params = {}, = {}) req = build_request(:update_launch_configuration, params) req.send_request() end |
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
2346 2347 2348 2349 |
# File 'lib/aws-sdk-drs/client.rb', line 2346 def update_replication_configuration(params = {}, = {}) req = build_request(:update_replication_configuration, params) req.send_request() end |
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
2484 2485 2486 2487 |
# File 'lib/aws-sdk-drs/client.rb', line 2484 def update_replication_configuration_template(params = {}, = {}) req = build_request(:update_replication_configuration_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2508 2509 2510 |
# File 'lib/aws-sdk-drs/client.rb', line 2508 def waiter_names [] end |