Class: Aws::Drs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Drs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-drs/client.rb
Overview
An API client for Drs. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Drs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
-
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
-
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
-
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID.
-
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID.
-
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID.
-
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
-
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs.
-
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
-
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
-
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
-
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
-
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery.
-
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery.
-
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
-
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
-
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
-
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
-
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a.
-
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
-
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started.
-
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance.
-
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers.
-
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources.
-
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
-
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
-
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
-
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
-
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
348 349 350 |
# File 'lib/aws-sdk-drs/client.rb', line 348 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2266 2267 2268 |
# File 'lib/aws-sdk-drs/client.rb', line 2266 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2269 2270 2271 |
# File 'lib/aws-sdk-drs/client.rb', line 2269 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-drs/client.rb', line 2244 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-drs' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#create_extended_source_server(params = {}) ⇒ Types::CreateExtendedSourceServerResponse
Create an extended source server in the target Account based on the source server in staging account.
436 437 438 439 |
# File 'lib/aws-sdk-drs/client.rb', line 436 def create_extended_source_server(params = {}, = {}) req = build_request(:create_extended_source_server, params) req.send_request() end |
#create_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Creates a new ReplicationConfigurationTemplate.
573 574 575 576 |
# File 'lib/aws-sdk-drs/client.rb', line 573 def create_replication_configuration_template(params = {}, = {}) req = build_request(:create_replication_configuration_template, params) req.send_request() end |
#delete_job(params = {}) ⇒ Struct
Deletes a single Job by ID.
595 596 597 598 |
# File 'lib/aws-sdk-drs/client.rb', line 595 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_recovery_instance(params = {}) ⇒ Struct
Deletes a single Recovery Instance by ID. This deletes the Recovery Instance resource from Elastic Disaster Recovery. The Recovery Instance must be disconnected first in order to delete it.
619 620 621 622 |
# File 'lib/aws-sdk-drs/client.rb', line 619 def delete_recovery_instance(params = {}, = {}) req = build_request(:delete_recovery_instance, params) req.send_request() end |
#delete_replication_configuration_template(params = {}) ⇒ Struct
Deletes a single Replication Configuration Template by ID
641 642 643 644 |
# File 'lib/aws-sdk-drs/client.rb', line 641 def delete_replication_configuration_template(params = {}, = {}) req = build_request(:delete_replication_configuration_template, params) req.send_request() end |
#delete_source_server(params = {}) ⇒ Struct
Deletes a single Source Server by ID. The Source Server must be disconnected first.
664 665 666 667 |
# File 'lib/aws-sdk-drs/client.rb', line 664 def delete_source_server(params = {}, = {}) req = build_request(:delete_source_server, params) req.send_request() end |
#describe_job_log_items(params = {}) ⇒ Types::DescribeJobLogItemsResponse
Retrieves a detailed Job log with pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
718 719 720 721 |
# File 'lib/aws-sdk-drs/client.rb', line 718 def describe_job_log_items(params = {}, = {}) req = build_request(:describe_job_log_items, params) req.send_request() end |
#describe_jobs(params = {}) ⇒ Types::DescribeJobsResponse
Returns a list of Jobs. Use the JobsID and fromDate and toDate filters to limit which jobs are returned. The response is sorted by creationDataTime - latest date first. Jobs are created by the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs. Jobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances, which are APIs available only to Support and only used in response to relevant support tickets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
781 782 783 784 |
# File 'lib/aws-sdk-drs/client.rb', line 781 def describe_jobs(params = {}, = {}) req = build_request(:describe_jobs, params) req.send_request() end |
#describe_recovery_instances(params = {}) ⇒ Types::DescribeRecoveryInstancesResponse
Lists all Recovery Instances or multiple Recovery Instances by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
877 878 879 880 |
# File 'lib/aws-sdk-drs/client.rb', line 877 def describe_recovery_instances(params = {}, = {}) req = build_request(:describe_recovery_instances, params) req.send_request() end |
#describe_recovery_snapshots(params = {}) ⇒ Types::DescribeRecoverySnapshotsResponse
Lists all Recovery Snapshots for a single Source Server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
934 935 936 937 |
# File 'lib/aws-sdk-drs/client.rb', line 934 def describe_recovery_snapshots(params = {}, = {}) req = build_request(:describe_recovery_snapshots, params) req.send_request() end |
#describe_replication_configuration_templates(params = {}) ⇒ Types::DescribeReplicationConfigurationTemplatesResponse
Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1000 1001 1002 1003 |
# File 'lib/aws-sdk-drs/client.rb', line 1000 def describe_replication_configuration_templates(params = {}, = {}) req = build_request(:describe_replication_configuration_templates, params) req.send_request() end |
#describe_source_servers(params = {}) ⇒ Types::DescribeSourceServersResponse
Lists all Source Servers or multiple Source Servers filtered by ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1096 1097 1098 1099 |
# File 'lib/aws-sdk-drs/client.rb', line 1096 def describe_source_servers(params = {}, = {}) req = build_request(:describe_source_servers, params) req.send_request() end |
#disconnect_recovery_instance(params = {}) ⇒ Struct
Disconnect a Recovery Instance from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Recovery Instance will be terminated / deleted within 90 minutes. If the agent on the Recovery Instance has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the Recovery Instance will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1130 1131 1132 1133 |
# File 'lib/aws-sdk-drs/client.rb', line 1130 def disconnect_recovery_instance(params = {}, = {}) req = build_request(:disconnect_recovery_instance, params) req.send_request() end |
#disconnect_source_server(params = {}) ⇒ Types::SourceServer
Disconnects a specific Source Server from Elastic Disaster Recovery. Data replication is stopped immediately. All AWS resources created by Elastic Disaster Recovery for enabling the replication of the Source Server will be terminated / deleted within 90 minutes. You cannot disconnect a Source Server if it has a Recovery Instance. If the agent on the Source Server has not been prevented from communicating with the Elastic Disaster Recovery service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be nullified.
1230 1231 1232 1233 |
# File 'lib/aws-sdk-drs/client.rb', line 1230 def disconnect_source_server(params = {}, = {}) req = build_request(:disconnect_source_server, params) req.send_request() end |
#get_failback_replication_configuration(params = {}) ⇒ Types::GetFailbackReplicationConfigurationResponse
Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.
1266 1267 1268 1269 |
# File 'lib/aws-sdk-drs/client.rb', line 1266 def get_failback_replication_configuration(params = {}, = {}) req = build_request(:get_failback_replication_configuration, params) req.send_request() end |
#get_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Gets a LaunchConfiguration, filtered by Source Server IDs.
1309 1310 1311 1312 |
# File 'lib/aws-sdk-drs/client.rb', line 1309 def get_launch_configuration(params = {}, = {}) req = build_request(:get_launch_configuration, params) req.send_request() end |
#get_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Gets a ReplicationConfiguration, filtered by Source Server ID.
1380 1381 1382 1383 |
# File 'lib/aws-sdk-drs/client.rb', line 1380 def get_replication_configuration(params = {}, = {}) req = build_request(:get_replication_configuration, params) req.send_request() end |
#initialize_service(params = {}) ⇒ Struct
Initialize Elastic Disaster Recovery.
1393 1394 1395 1396 |
# File 'lib/aws-sdk-drs/client.rb', line 1393 def initialize_service(params = {}, = {}) req = build_request(:initialize_service, params) req.send_request() end |
#list_extensible_source_servers(params = {}) ⇒ Types::ListExtensibleSourceServersResponse
Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1441 1442 1443 1444 |
# File 'lib/aws-sdk-drs/client.rb', line 1441 def list_extensible_source_servers(params = {}, = {}) req = build_request(:list_extensible_source_servers, params) req.send_request() end |
#list_staging_accounts(params = {}) ⇒ Types::ListStagingAccountsResponse
Returns an array of staging accounts for existing extended source servers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1479 1480 1481 1482 |
# File 'lib/aws-sdk-drs/client.rb', line 1479 def list_staging_accounts(params = {}, = {}) req = build_request(:list_staging_accounts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags for your Elastic Disaster Recovery resources.
1508 1509 1510 1511 |
# File 'lib/aws-sdk-drs/client.rb', line 1508 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#retry_data_replication(params = {}) ⇒ Types::SourceServer
Causes the data replication initiation sequence to begin immediately upon next Handshake for the specified Source Server ID, regardless of when the previous initiation started. This command will work only if the Source Server is stalled or is in a DISCONNECTED or STOPPED state.
1598 1599 1600 1601 |
# File 'lib/aws-sdk-drs/client.rb', line 1598 def retry_data_replication(params = {}, = {}) req = build_request(:retry_data_replication, params) req.send_request() end |
#start_failback_launch(params = {}) ⇒ Types::StartFailbackLaunchResponse
Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance. This will run conversion on the failback client and will reboot your machine, thus completing the failback process.
1648 1649 1650 1651 |
# File 'lib/aws-sdk-drs/client.rb', line 1648 def start_failback_launch(params = {}, = {}) req = build_request(:start_failback_launch, params) req.send_request() end |
#start_recovery(params = {}) ⇒ Types::StartRecoveryResponse
Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.
1705 1706 1707 1708 |
# File 'lib/aws-sdk-drs/client.rb', line 1705 def start_recovery(params = {}, = {}) req = build_request(:start_recovery, params) req.send_request() end |
#stop_failback(params = {}) ⇒ Struct
Stops the failback process for a specified Recovery Instance. This changes the Failback State of the Recovery Instance back to FAILBACK_NOT_STARTED.
1729 1730 1731 1732 |
# File 'lib/aws-sdk-drs/client.rb', line 1729 def stop_failback(params = {}, = {}) req = build_request(:stop_failback, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.
1761 1762 1763 1764 |
# File 'lib/aws-sdk-drs/client.rb', line 1761 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_recovery_instances(params = {}) ⇒ Types::TerminateRecoveryInstancesResponse
Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service.
1803 1804 1805 1806 |
# File 'lib/aws-sdk-drs/client.rb', line 1803 def terminate_recovery_instances(params = {}, = {}) req = build_request(:terminate_recovery_instances, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources.
1830 1831 1832 1833 |
# File 'lib/aws-sdk-drs/client.rb', line 1830 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_failback_replication_configuration(params = {}) ⇒ Struct
Allows you to update the failback replication configuration of a Recovery Instance by ID.
1867 1868 1869 1870 |
# File 'lib/aws-sdk-drs/client.rb', line 1867 def update_failback_replication_configuration(params = {}, = {}) req = build_request(:update_failback_replication_configuration, params) req.send_request() end |
#update_launch_configuration(params = {}) ⇒ Types::LaunchConfiguration
Updates a LaunchConfiguration by Source Server ID.
1941 1942 1943 1944 |
# File 'lib/aws-sdk-drs/client.rb', line 1941 def update_launch_configuration(params = {}, = {}) req = build_request(:update_launch_configuration, params) req.send_request() end |
#update_replication_configuration(params = {}) ⇒ Types::ReplicationConfiguration
Allows you to update a ReplicationConfiguration by Source Server ID.
2097 2098 2099 2100 |
# File 'lib/aws-sdk-drs/client.rb', line 2097 def update_replication_configuration(params = {}, = {}) req = build_request(:update_replication_configuration, params) req.send_request() end |
#update_replication_configuration_template(params = {}) ⇒ Types::ReplicationConfigurationTemplate
Updates a ReplicationConfigurationTemplate by ID.
2235 2236 2237 2238 |
# File 'lib/aws-sdk-drs/client.rb', line 2235 def update_replication_configuration_template(params = {}, = {}) req = build_request(:update_replication_configuration_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2259 2260 2261 |
# File 'lib/aws-sdk-drs/client.rb', line 2259 def waiter_names [] end |