Class: Aws::Drs::Types::CreateExtendedSourceServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::CreateExtendedSourceServerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass CreateExtendedSourceServerRequest data as a hash:
{
source_server_arn: "SourceServerARN", # required
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#source_server_arn ⇒ String
This defines the ARN of the source server in staging Account based on which you want to create an extended source server.
-
#tags ⇒ Hash<String,String>
A list of tags associated with the extended source server.
Instance Attribute Details
#source_server_arn ⇒ String
This defines the ARN of the source server in staging Account based on which you want to create an extended source server.
147 148 149 150 151 152 |
# File 'lib/aws-sdk-drs/types.rb', line 147 class CreateExtendedSourceServerRequest < Struct.new( :source_server_arn, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags associated with the extended source server.
147 148 149 150 151 152 |
# File 'lib/aws-sdk-drs/types.rb', line 147 class CreateExtendedSourceServerRequest < Struct.new( :source_server_arn, :tags) SENSITIVE = [:tags] include Aws::Structure end |