Class: Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_disposition ⇒ String
Launch disposition.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
-
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Copy private IP.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/aws-sdk-drs/types.rb', line 220 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :post_launch_enabled, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |