Class: Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::CreateLaunchConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_disposition ⇒ String
Launch disposition.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Copy private IP.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Request to associate tags during creation of a Launch Configuration Template.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-drs/types.rb', line 216 class CreateLaunchConfigurationTemplateRequest < Struct.new( :copy_private_ip, :copy_tags, :export_bucket_arn, :launch_disposition, :licensing, :tags, :target_instance_type_right_sizing_method) SENSITIVE = [:tags] include Aws::Structure end |