Class: Aws::Drs::Types::CreateRecoveryPlanStepRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::CreateRecoveryPlanStepRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique string provided to ensure request idempotency.
-
#configuration ⇒ Types::RecoveryPlanStepConfiguration
Type-specific configuration for a recovery plan step.
-
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan to add the step to.
-
#step_name ⇒ String
The name of a Recovery Plan Step.
-
#step_order ⇒ Integer
The order of a step within a Recovery Plan (1-based).
Instance Attribute Details
#client_token ⇒ String
A unique string provided to ensure request idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-drs/types.rb', line 355 class CreateRecoveryPlanStepRequest < Struct.new( :recovery_plan_arn, :step_name, :step_order, :configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::RecoveryPlanStepConfiguration
Type-specific configuration for a recovery plan step. Exactly one member must be set.
355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-drs/types.rb', line 355 class CreateRecoveryPlanStepRequest < Struct.new( :recovery_plan_arn, :step_name, :step_order, :configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan to add the step to.
355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-drs/types.rb', line 355 class CreateRecoveryPlanStepRequest < Struct.new( :recovery_plan_arn, :step_name, :step_order, :configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#step_name ⇒ String
The name of a Recovery Plan Step.
355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-drs/types.rb', line 355 class CreateRecoveryPlanStepRequest < Struct.new( :recovery_plan_arn, :step_name, :step_order, :configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#step_order ⇒ Integer
The order of a step within a Recovery Plan (1-based).
355 356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-drs/types.rb', line 355 class CreateRecoveryPlanStepRequest < Struct.new( :recovery_plan_arn, :step_name, :step_order, :configuration, :client_token) SENSITIVE = [] include Aws::Structure end |