Class: Aws::Drs::Types::Disk

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

An object representing a data storage device on a server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytesInteger

The amount of storage on the disk in bytes.

Returns:

  • (Integer)


1137
1138
1139
1140
1141
1142
# File 'lib/aws-sdk-drs/types.rb', line 1137

class Disk < Struct.new(
  :device_name,
  :bytes)
  SENSITIVE = []
  include Aws::Structure
end

#device_nameString

The disk or device name.

Returns:

  • (String)


1137
1138
1139
1140
1141
1142
# File 'lib/aws-sdk-drs/types.rb', line 1137

class Disk < Struct.new(
  :device_name,
  :bytes)
  SENSITIVE = []
  include Aws::Structure
end