Class: Aws::Drs::Types::GetFailbackReplicationConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::GetFailbackReplicationConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
-
#internet_protocol ⇒ String
Which version of the Internet Protocol to use for replication of data.
-
#name ⇒ String
The name of the Failback Replication Configuration.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
-
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
Instance Attribute Details
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-drs/types.rb', line 1229 class GetFailbackReplicationConfigurationResponse < Struct.new( :recovery_instance_id, :name, :bandwidth_throttling, :use_private_ip, :internet_protocol) SENSITIVE = [] include Aws::Structure end |
#internet_protocol ⇒ String
Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6)
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-drs/types.rb', line 1229 class GetFailbackReplicationConfigurationResponse < Struct.new( :recovery_instance_id, :name, :bandwidth_throttling, :use_private_ip, :internet_protocol) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Failback Replication Configuration.
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-drs/types.rb', line 1229 class GetFailbackReplicationConfigurationResponse < Struct.new( :recovery_instance_id, :name, :bandwidth_throttling, :use_private_ip, :internet_protocol) SENSITIVE = [] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-drs/types.rb', line 1229 class GetFailbackReplicationConfigurationResponse < Struct.new( :recovery_instance_id, :name, :bandwidth_throttling, :use_private_ip, :internet_protocol) SENSITIVE = [] include Aws::Structure end |
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-drs/types.rb', line 1229 class GetFailbackReplicationConfigurationResponse < Struct.new( :recovery_instance_id, :name, :bandwidth_throttling, :use_private_ip, :internet_protocol) SENSITIVE = [] include Aws::Structure end |