Class: Aws::Drs::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

A job is an asynchronous workflow.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of a Job.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#creation_date_timeString

The date and time of when the Job was created.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#end_date_timeString

The date and time of when the Job ended.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#initiated_byString

A string representing who initiated the Job.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#job_idString

The ID of the Job.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#participating_resourcesArray<Types::ParticipatingResource>

A list of resources that the Job is acting upon.

Returns:



1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#participating_serversArray<Types::ParticipatingServer>

A list of servers that the Job is acting upon.

Returns:



1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#statusString

The status of the Job.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

A list of tags associated with the Job.

Returns:

  • (Hash<String,String>)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#typeString

The type of the Job.

Returns:

  • (String)


1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/aws-sdk-drs/types.rb', line 1367

class Job < Struct.new(
  :job_id,
  :arn,
  :type,
  :initiated_by,
  :creation_date_time,
  :end_date_time,
  :status,
  :participating_servers,
  :tags,
  :participating_resources)
  SENSITIVE = [:tags]
  include Aws::Structure
end