Class: Aws::Drs::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

A job is an asynchronous workflow.

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of a Job.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#creation_date_timeString

The date and time of when the Job was created.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#end_date_timeString

The date and time of when the Job ended.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#initiated_byString

A string representing who initiated the Job.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#job_idString

The ID of the Job.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#participating_serversArray<Types::ParticipatingServer>

A list of servers that the Job is acting upon.

Returns:



1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#statusString

The status of the Job.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

A list of tags associated with the Job.

Returns:

  • (Hash<String,String>)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#typeString

The type of the Job.

Returns:

  • (String)


1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
# File 'lib/aws-sdk-drs/types.rb', line 1193

class Job < Struct.new(
  :arn,
  :creation_date_time,
  :end_date_time,
  :initiated_by,
  :job_id,
  :participating_servers,
  :status,
  :tags,
  :type)
  SENSITIVE = [:tags]
  include Aws::Structure
end