Class: Aws::Drs::Types::LaunchConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_private_ipBoolean

Whether we should copy the Private IP of the Source Server to the Recovery Instance.

Returns:

  • (Boolean)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#copy_tagsBoolean

Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.

Returns:

  • (Boolean)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_launch_template_idString

The EC2 launch template ID of this launch configuration.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#launch_dispositionString

The state of the Recovery Instance in EC2 after the recovery operation.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#launch_into_instance_propertiesTypes::LaunchIntoInstanceProperties

Launch into existing instance properties.



1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#licensingTypes::Licensing

The licensing configuration to be used for this launch configuration.

Returns:



1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the launch configuration.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#post_launch_enabledBoolean

Whether we want to activate post-launch actions for the Source Server.

Returns:

  • (Boolean)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_modeString

Recovery mode.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server for this launch configuration.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end

#target_instance_type_right_sizing_methodString

Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.

Returns:

  • (String)


1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/aws-sdk-drs/types.rb', line 1976

class LaunchConfiguration < Struct.new(
  :source_server_id,
  :name,
  :ec2_launch_template_id,
  :launch_disposition,
  :target_instance_type_right_sizing_method,
  :copy_private_ip,
  :copy_tags,
  :licensing,
  :post_launch_enabled,
  :launch_into_instance_properties,
  :recovery_mode)
  SENSITIVE = []
  include Aws::Structure
end