Class: Aws::Drs::Types::LaunchConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LaunchConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
-
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
-
#ec2_launch_template_id ⇒ String
The EC2 launch template ID of this launch configuration.
-
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
-
#launch_into_instance_properties ⇒ Types::LaunchIntoInstanceProperties
Launch into existing instance properties.
-
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
-
#name ⇒ String
The name of the launch configuration.
-
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions for the Source Server.
-
#source_server_id ⇒ String
The ID of the Source Server for this launch configuration.
-
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#ec2_launch_template_id ⇒ String
The EC2 launch template ID of this launch configuration.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#launch_into_instance_properties ⇒ Types::LaunchIntoInstanceProperties
Launch into existing instance properties.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the launch configuration.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions for the Source Server.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server for this launch configuration.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-drs/types.rb', line 1652 class LaunchConfiguration < Struct.new( :source_server_id, :name, :ec2_launch_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties) SENSITIVE = [] include Aws::Structure end |