Class: Aws::Drs::Types::LaunchConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LaunchConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
-
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
-
#ec2_launch_template_id ⇒ String
The EC2 launch template ID of this launch configuration.
-
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
-
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
-
#name ⇒ String
The name of the launch configuration.
-
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions for the Source Server.
-
#source_server_id ⇒ String
The ID of the Source Server for this launch configuration.
-
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#ec2_launch_template_id ⇒ String
The EC2 launch template ID of this launch configuration.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the launch configuration.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions for the Source Server.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server for this launch configuration.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-drs/types.rb', line 1602 class LaunchConfiguration < Struct.new( :copy_private_ip, :copy_tags, :ec2_launch_template_id, :launch_disposition, :licensing, :name, :post_launch_enabled, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |