Class: Aws::Drs::Types::LaunchConfigurationTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LaunchConfigurationTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Account level Launch Configuration Template.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN of the Launch Configuration Template.
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_configuration_template_id ⇒ String
ID of the Launch Configuration Template.
-
#launch_disposition ⇒ String
Launch disposition.
-
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#post_launch_enabled ⇒ Boolean
Post-launch actions activated.
-
#recovery_mode ⇒ String
Recovery mode.
-
#tags ⇒ Hash<String,String>
Tags of the Launch Configuration Template.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#arn ⇒ String
ARN of the Launch Configuration Template.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#copy_private_ip ⇒ Boolean
Copy private IP.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
ID of the Launch Configuration Template.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Post-launch actions activated.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_mode ⇒ String
Recovery mode.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags of the Launch Configuration Template.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-drs/types.rb', line 1731 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [:tags] include Aws::Structure end |