Class: Aws::Drs::Types::LaunchConfigurationTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LaunchConfigurationTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Account level Launch Configuration Template.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN of the Launch Configuration Template.
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_configuration_template_id ⇒ String
ID of the Launch Configuration Template.
-
#launch_disposition ⇒ String
Launch disposition.
-
#launch_into_source_instance ⇒ Boolean
DRS will set the ‘launch into instance ID’ of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#post_launch_enabled ⇒ Boolean
Post-launch actions activated.
-
#tags ⇒ Hash<String,String>
Tags of the Launch Configuration Template.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#arn ⇒ String
ARN of the Launch Configuration Template.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#copy_private_ip ⇒ Boolean
Copy private IP.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
ID of the Launch Configuration Template.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#launch_into_source_instance ⇒ Boolean
DRS will set the ‘launch into instance ID’ of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Post-launch actions activated.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags of the Launch Configuration Template.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/aws-sdk-drs/types.rb', line 1717 class LaunchConfigurationTemplate < Struct.new( :launch_configuration_template_id, :arn, :tags, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance) SENSITIVE = [:tags] include Aws::Structure end |