Class: Aws::Drs::Types::LifeCycleLastLaunch
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::LifeCycleLastLaunch
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
An object containing information regarding the last launch of a Source Server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#initiated ⇒ Types::LifeCycleLastLaunchInitiated
An object containing information regarding the initiation of the last launch of a Source Server.
Instance Attribute Details
#initiated ⇒ Types::LifeCycleLastLaunchInitiated
An object containing information regarding the initiation of the last launch of a Source Server.
1170 1171 1172 1173 1174 |
# File 'lib/aws-sdk-drs/types.rb', line 1170 class LifeCycleLastLaunch < Struct.new( :initiated) SENSITIVE = [] include Aws::Structure end |