Class: Aws::Drs::Types::ProductCode
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ProductCode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Properties of a product code associated with a volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#product_code_id ⇒ String
Id of a product code associated with a volume.
-
#product_code_mode ⇒ String
Mode of a product code associated with a volume.
Instance Attribute Details
#product_code_id ⇒ String
Id of a product code associated with a volume.
2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-drs/types.rb', line 2648 class ProductCode < Struct.new( :product_code_id, :product_code_mode) SENSITIVE = [] include Aws::Structure end |
#product_code_mode ⇒ String
Mode of a product code associated with a volume.
2648 2649 2650 2651 2652 2653 |
# File 'lib/aws-sdk-drs/types.rb', line 2648 class ProductCode < Struct.new( :product_code_id, :product_code_mode) SENSITIVE = [] include Aws::Structure end |