Class: Aws::Drs::Types::PutLaunchActionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::PutLaunchActionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_code ⇒ String
Launch action code.
-
#action_id ⇒ String
Launch action Id.
-
#action_version ⇒ String
Launch action version.
-
#active ⇒ Boolean
Whether the launch action is active.
-
#category ⇒ String
Launch action category.
-
#description ⇒ String
Launch action description.
-
#name ⇒ String
Launch action name.
-
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
-
#order ⇒ Integer
Launch action order.
-
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
-
#resource_id ⇒ String
Launch configuration template Id or Source Server Id.
-
#type ⇒ String
Launch action type.
Instance Attribute Details
#action_code ⇒ String
Launch action code.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#action_id ⇒ String
Launch action Id.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#action_version ⇒ String
Launch action version.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#active ⇒ Boolean
Whether the launch action is active.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
Launch action category.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Launch action description.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Launch action name.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#optional ⇒ Boolean
Whether the launch will not be marked as failed if this action fails.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#order ⇒ Integer
Launch action order.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::LaunchActionParameter>
Launch action parameters.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Launch configuration template Id or Source Server Id
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Launch action type.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/aws-sdk-drs/types.rb', line 2206 class PutLaunchActionResponse < Struct.new( :action_code, :action_id, :action_version, :active, :category, :description, :name, :optional, :order, :parameters, :resource_id, :type) SENSITIVE = [] include Aws::Structure end |