Class: Aws::Drs::Types::RecoveryInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
A Recovery Instance is a replica of a Source Server running on EC2.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#agent_version ⇒ String
The version of the DRS agent installed on the recovery instance.
-
#arn ⇒ String
The ARN of the Recovery Instance.
-
#data_replication_info ⇒ Types::RecoveryInstanceDataReplicationInfo
The Data Replication Info of the Recovery Instance.
-
#ec2_instance_id ⇒ String
The EC2 instance ID of the Recovery Instance.
-
#ec2_instance_state ⇒ String
The state of the EC2 instance for this Recovery Instance.
-
#failback ⇒ Types::RecoveryInstanceFailback
An object representing failback related information of the Recovery Instance.
-
#is_drill ⇒ Boolean
Whether this Recovery Instance was created for a drill or for an actual Recovery event.
-
#job_id ⇒ String
The ID of the Job that created the Recovery Instance.
-
#origin_availability_zone ⇒ String
AWS availability zone associated with the recovery instance.
-
#origin_environment ⇒ String
Environment (On Premises / AWS) of the instance that the recovery instance originated from.
-
#point_in_time_snapshot_date_time ⇒ String
The date and time of the Point in Time (PIT) snapshot that this Recovery Instance was launched from.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
-
#recovery_instance_properties ⇒ Types::RecoveryInstanceProperties
Properties of the Recovery Instance machine.
-
#source_outpost_arn ⇒ String
The ARN of the source Outpost.
-
#source_server_id ⇒ String
The Source Server ID that this Recovery Instance is associated with.
-
#tags ⇒ Hash<String,String>
An array of tags that are associated with the Recovery Instance.
Instance Attribute Details
#agent_version ⇒ String
The version of the DRS agent installed on the recovery instance
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#arn ⇒ String
The ARN of the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#data_replication_info ⇒ Types::RecoveryInstanceDataReplicationInfo
The Data Replication Info of the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#ec2_instance_id ⇒ String
The EC2 instance ID of the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#ec2_instance_state ⇒ String
The state of the EC2 instance for this Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#failback ⇒ Types::RecoveryInstanceFailback
An object representing failback related information of the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#is_drill ⇒ Boolean
Whether this Recovery Instance was created for a drill or for an actual Recovery event.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#job_id ⇒ String
The ID of the Job that created the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#origin_availability_zone ⇒ String
AWS availability zone associated with the recovery instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#origin_environment ⇒ String
Environment (On Premises / AWS) of the instance that the recovery instance originated from.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#point_in_time_snapshot_date_time ⇒ String
The date and time of the Point in Time (PIT) snapshot that this Recovery Instance was launched from.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_properties ⇒ Types::RecoveryInstanceProperties
Properties of the Recovery Instance machine.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#source_outpost_arn ⇒ String
The ARN of the source Outpost
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#source_server_id ⇒ String
The Source Server ID that this Recovery Instance is associated with.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of tags that are associated with the Recovery Instance.
2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-drs/types.rb', line 2368 class RecoveryInstance < Struct.new( :ec2_instance_id, :ec2_instance_state, :job_id, :recovery_instance_id, :source_server_id, :arn, :tags, :failback, :data_replication_info, :recovery_instance_properties, :point_in_time_snapshot_date_time, :is_drill, :origin_environment, :origin_availability_zone, :agent_version, :source_outpost_arn) SENSITIVE = [:tags] include Aws::Structure end |