Class: Aws::Drs::Types::RecoveryInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
A Recovery Instance is a replica of a Source Server running on EC2.
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Recovery Instance.
-
#data_replication_info ⇒ Types::RecoveryInstanceDataReplicationInfo
The Data Replication Info of the Recovery Instance.
-
#ec2_instance_id ⇒ String
The EC2 instance ID of the Recovery Instance.
-
#ec2_instance_state ⇒ String
The state of the EC2 instance for this Recovery Instance.
-
#failback ⇒ Types::RecoveryInstanceFailback
An object representing failback related information of the Recovery Instance.
-
#is_drill ⇒ Boolean
Whether this Recovery Instance was created for a drill or for an actual Recovery event.
-
#job_id ⇒ String
The ID of the Job that created the Recovery Instance.
-
#origin_availability_zone ⇒ String
AWS availability zone associated with the recovery instance.
-
#origin_environment ⇒ String
Environment (On Premises / AWS) of the instance that the recovery instance originated from.
-
#point_in_time_snapshot_date_time ⇒ String
The date and time of the Point in Time (PIT) snapshot that this Recovery Instance was launched from.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
-
#recovery_instance_properties ⇒ Types::RecoveryInstanceProperties
Properties of the Recovery Instance machine.
-
#source_server_id ⇒ String
The Source Server ID that this Recovery Instance is associated with.
-
#tags ⇒ Hash<String,String>
An array of tags that are associated with the Recovery Instance.
Instance Attribute Details
#arn ⇒ String
The ARN of the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#data_replication_info ⇒ Types::RecoveryInstanceDataReplicationInfo
The Data Replication Info of the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#ec2_instance_id ⇒ String
The EC2 instance ID of the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#ec2_instance_state ⇒ String
The state of the EC2 instance for this Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#failback ⇒ Types::RecoveryInstanceFailback
An object representing failback related information of the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#is_drill ⇒ Boolean
Whether this Recovery Instance was created for a drill or for an actual Recovery event.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#job_id ⇒ String
The ID of the Job that created the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#origin_availability_zone ⇒ String
AWS availability zone associated with the recovery instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#origin_environment ⇒ String
Environment (On Premises / AWS) of the instance that the recovery instance originated from.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#point_in_time_snapshot_date_time ⇒ String
The date and time of the Point in Time (PIT) snapshot that this Recovery Instance was launched from.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_properties ⇒ Types::RecoveryInstanceProperties
Properties of the Recovery Instance machine.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_server_id ⇒ String
The Source Server ID that this Recovery Instance is associated with.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of tags that are associated with the Recovery Instance.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/aws-sdk-drs/types.rb', line 2252 class RecoveryInstance < Struct.new( :arn, :data_replication_info, :ec2_instance_id, :ec2_instance_state, :failback, :is_drill, :job_id, :origin_availability_zone, :origin_environment, :point_in_time_snapshot_date_time, :recovery_instance_id, :recovery_instance_properties, :source_server_id, :tags) SENSITIVE = [:tags] include Aws::Structure end |