Class: Aws::Drs::Types::RecoveryInstanceDisk
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryInstanceDisk
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
An object representing a block storage device on the Recovery Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
-
#ebs_volume_id ⇒ String
The EBS Volume ID of this disk.
-
#internal_device_name ⇒ String
The internal device name of this disk.
Instance Attribute Details
#bytes ⇒ Integer
The amount of storage on the disk in bytes.
2495 2496 2497 2498 2499 2500 2501 |
# File 'lib/aws-sdk-drs/types.rb', line 2495 class RecoveryInstanceDisk < Struct.new( :bytes, :ebs_volume_id, :internal_device_name) SENSITIVE = [] include Aws::Structure end |
#ebs_volume_id ⇒ String
The EBS Volume ID of this disk.
2495 2496 2497 2498 2499 2500 2501 |
# File 'lib/aws-sdk-drs/types.rb', line 2495 class RecoveryInstanceDisk < Struct.new( :bytes, :ebs_volume_id, :internal_device_name) SENSITIVE = [] include Aws::Structure end |
#internal_device_name ⇒ String
The internal device name of this disk. This is the name that is visible on the machine itself and not from the EC2 console.
2495 2496 2497 2498 2499 2500 2501 |
# File 'lib/aws-sdk-drs/types.rb', line 2495 class RecoveryInstanceDisk < Struct.new( :bytes, :ebs_volume_id, :internal_device_name) SENSITIVE = [] include Aws::Structure end |