Class: Aws::Drs::Types::RecoveryInstanceFailback
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryInstanceFailback
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
An object representing failback related information of the Recovery Instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_last_seen_by_service_date_time ⇒ String
The date and time the agent on the Recovery Instance was last seen by the service.
-
#elapsed_replication_duration ⇒ String
The amount of time that the Recovery Instance has been replicating for.
-
#failback_client_id ⇒ String
The ID of the failback client that this Recovery Instance is associated with.
-
#failback_client_last_seen_by_service_date_time ⇒ String
The date and time that the failback client was last seen by the service.
-
#failback_initiation_time ⇒ String
The date and time that the failback initiation started.
-
#failback_job_id ⇒ String
The Job ID of the last failback log for this Recovery Instance.
-
#failback_launch_type ⇒ String
The launch type (Recovery / Drill) of the last launch for the failback replication of this recovery instance.
-
#failback_to_original_server ⇒ Boolean
Whether we are failing back to the original Source Server for this Recovery Instance.
-
#first_byte_date_time ⇒ String
The date and time of the first byte that was replicated from the Recovery Instance.
-
#state ⇒ String
The state of the failback process that this Recovery Instance is in.
Instance Attribute Details
#agent_last_seen_by_service_date_time ⇒ String
The date and time the agent on the Recovery Instance was last seen by the service.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#elapsed_replication_duration ⇒ String
The amount of time that the Recovery Instance has been replicating for.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_client_id ⇒ String
The ID of the failback client that this Recovery Instance is associated with.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_client_last_seen_by_service_date_time ⇒ String
The date and time that the failback client was last seen by the service.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_initiation_time ⇒ String
The date and time that the failback initiation started.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_job_id ⇒ String
The Job ID of the last failback log for this Recovery Instance.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_launch_type ⇒ String
The launch type (Recovery / Drill) of the last launch for the failback replication of this recovery instance.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#failback_to_original_server ⇒ Boolean
Whether we are failing back to the original Source Server for this Recovery Instance.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#first_byte_date_time ⇒ String
The date and time of the first byte that was replicated from the Recovery Instance.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the failback process that this Recovery Instance is in.
2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/aws-sdk-drs/types.rb', line 2485 class RecoveryInstanceFailback < Struct.new( :agent_last_seen_by_service_date_time, :elapsed_replication_duration, :failback_client_id, :failback_client_last_seen_by_service_date_time, :failback_initiation_time, :failback_job_id, :failback_launch_type, :failback_to_original_server, :first_byte_date_time, :state) SENSITIVE = [] include Aws::Structure end |