Class: Aws::Drs::Types::RecoveryPlanStepConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::RecoveryPlanStepConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
RecoveryPlanStepConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
RecoveryPlanStepConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RecoveryPlanStepConfiguration corresponding to the set member.
Type-specific configuration for a recovery plan step. Exactly one member must be set.
Defined Under Namespace
Classes: ServerStepConfiguration, Unknown, WaitStepConfiguration
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#server_step_configuration ⇒ Types::ServerStepConfiguration
Configuration for a SERVER type step.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#wait_step_configuration ⇒ Types::WaitStepConfiguration
Configuration for a WAIT type step.
Instance Attribute Details
#server_step_configuration ⇒ Types::ServerStepConfiguration
Configuration for a SERVER type step.
3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'lib/aws-sdk-drs/types.rb', line 3562 class RecoveryPlanStepConfiguration < Struct.new( :server_step_configuration, :wait_step_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ServerStepConfiguration < RecoveryPlanStepConfiguration; end class WaitStepConfiguration < RecoveryPlanStepConfiguration; end class Unknown < RecoveryPlanStepConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3562 3563 3564 |
# File 'lib/aws-sdk-drs/types.rb', line 3562 def unknown @unknown end |
#wait_step_configuration ⇒ Types::WaitStepConfiguration
Configuration for a WAIT type step.
3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'lib/aws-sdk-drs/types.rb', line 3562 class RecoveryPlanStepConfiguration < Struct.new( :server_step_configuration, :wait_step_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ServerStepConfiguration < RecoveryPlanStepConfiguration; end class WaitStepConfiguration < RecoveryPlanStepConfiguration; end class Unknown < RecoveryPlanStepConfiguration; end end |