Class: Aws::Drs::Types::RecoverySnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

A snapshot of a Source Server used during recovery.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ebs_snapshotsArray<String>

A list of EBS snapshots.

Returns:

  • (Array<String>)


2716
2717
2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-drs/types.rb', line 2716

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#expected_timestampString

The timestamp of when we expect the snapshot to be taken.

Returns:

  • (String)


2716
2717
2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-drs/types.rb', line 2716

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the Recovery Snapshot.

Returns:

  • (String)


2716
2717
2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-drs/types.rb', line 2716

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server that the snapshot was taken for.

Returns:

  • (String)


2716
2717
2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-drs/types.rb', line 2716

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#timestampString

The actual timestamp that the snapshot was taken.

Returns:

  • (String)


2716
2717
2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-drs/types.rb', line 2716

class RecoverySnapshot < Struct.new(
  :snapshot_id,
  :source_server_id,
  :expected_timestamp,
  :timestamp,
  :ebs_snapshots)
  SENSITIVE = []
  include Aws::Structure
end