Class: Aws::Drs::Types::ReplicationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ReplicationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:staging_area_tags]
Instance Attribute Summary collapse
-
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration.
-
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
-
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
-
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
-
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
-
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
-
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
-
#name ⇒ String
The name of the Replication Configuration.
-
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
-
#replicated_disks ⇒ Array<Types::ReplicationConfigurationReplicatedDisk>
The configuration of the disks of the Source Server to be replicated.
-
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
-
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
-
#source_server_id ⇒ String
The ID of the Source Server for this Replication Configuration.
-
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
-
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
-
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
Instance Attribute Details
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#name ⇒ String
The name of the Replication Configuration.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replicated_disks ⇒ Array<Types::ReplicationConfigurationReplicatedDisk>
The configuration of the disks of the Source Server to be replicated.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server for this Replication Configuration.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-drs/types.rb', line 2037 class ReplicationConfiguration < Struct.new( :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :name, :pit_policy, :replicated_disks, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :source_server_id, :staging_area_subnet_id, :staging_area_tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags] include Aws::Structure end |