Class: Aws::Drs::Types::ReplicationConfigurationTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::ReplicationConfigurationTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:staging_area_tags, :tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Replication Configuration Template ARN.
-
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration Template.
-
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
-
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
-
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
-
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
-
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
-
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
-
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
-
#replication_configuration_template_id ⇒ String
The Replication Configuration Template ID.
-
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
-
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
-
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
-
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
-
#tags ⇒ Hash<String,String>
A set of tags to be associated with the Replication Configuration Template resource.
-
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
Instance Attribute Details
#arn ⇒ String
The Replication Configuration Template ARN.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#associate_default_security_group ⇒ Boolean
Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration Template.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#auto_replicate_new_disks ⇒ Boolean
Whether to allow the AWS replication agent to automatically replicate newly added disks.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#create_public_ip ⇒ Boolean
Whether to create a Public IP for the Recovery Instance by default.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#data_plane_routing ⇒ String
The data plane routing mechanism that will be used for replication.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#default_large_staging_disk_type ⇒ String
The Staging Disk EBS volume type to be used during replication.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#ebs_encryption ⇒ String
The type of EBS encryption to be used during replication.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#ebs_encryption_key_arn ⇒ String
The ARN of the EBS encryption key to be used during replication.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#pit_policy ⇒ Array<Types::PITPolicyRule>
The Point in time (PIT) policy to manage snapshots taken during replication.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#replication_configuration_template_id ⇒ String
The Replication Configuration Template ID.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#replication_server_instance_type ⇒ String
The instance type to be used for the replication server.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#replication_servers_security_groups_i_ds ⇒ Array<String>
The security group IDs that will be used by the replication server.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#staging_area_subnet_id ⇒ String
The subnet to be used by the replication staging area.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#staging_area_tags ⇒ Hash<String,String>
A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of tags to be associated with the Replication Configuration Template resource.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |
#use_dedicated_replication_server ⇒ Boolean
Whether to use a dedicated Replication Server in the replication staging area.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 |
# File 'lib/aws-sdk-drs/types.rb', line 2457 class ReplicationConfigurationTemplate < Struct.new( :arn, :associate_default_security_group, :auto_replicate_new_disks, :bandwidth_throttling, :create_public_ip, :data_plane_routing, :default_large_staging_disk_type, :ebs_encryption, :ebs_encryption_key_arn, :pit_policy, :replication_configuration_template_id, :replication_server_instance_type, :replication_servers_security_groups_i_ds, :staging_area_subnet_id, :staging_area_tags, :tags, :use_dedicated_replication_server) SENSITIVE = [:staging_area_tags, :tags] include Aws::Structure end |