Class: Aws::Drs::Types::SourceNetwork
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::SourceNetwork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
The ARN of the Source Network.
Constant Summary collapse
- SENSITIVE =
[:tags, :replication_status_details, :cfn_stack_name]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Source Network.
-
#cfn_stack_name ⇒ String
CloudFormation stack name that was deployed for recovering the Source Network.
-
#last_recovery ⇒ Types::RecoveryLifeCycle
An object containing information regarding the last recovery of the Source Network.
-
#launched_vpc_id ⇒ String
ID of the recovered VPC following Source Network recovery.
-
#replication_status ⇒ String
Status of Source Network Replication.
-
#replication_status_details ⇒ String
Error details in case Source Network replication status is ERROR.
-
#source_account_id ⇒ String
Account ID containing the VPC protected by the Source Network.
-
#source_network_id ⇒ String
Source Network ID.
-
#source_region ⇒ String
Region containing the VPC protected by the Source Network.
-
#source_vpc_id ⇒ String
VPC ID protected by the Source Network.
-
#tags ⇒ Hash<String,String>
A list of tags associated with the Source Network.
Instance Attribute Details
#arn ⇒ String
The ARN of the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#cfn_stack_name ⇒ String
CloudFormation stack name that was deployed for recovering the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#last_recovery ⇒ Types::RecoveryLifeCycle
An object containing information regarding the last recovery of the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#launched_vpc_id ⇒ String
ID of the recovered VPC following Source Network recovery.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#replication_status ⇒ String
Status of Source Network Replication. Possible values: (a) STOPPED - Source Network is not replicating. (b) IN_PROGRESS - Source Network is being replicated. © PROTECTED - Source Network was replicated successfully and is being synchronized for changes. (d) ERROR - Source Network replication has failed
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#replication_status_details ⇒ String
Error details in case Source Network replication status is ERROR.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#source_account_id ⇒ String
Account ID containing the VPC protected by the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#source_network_id ⇒ String
Source Network ID.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#source_region ⇒ String
Region containing the VPC protected by the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#source_vpc_id ⇒ String
VPC ID protected by the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags associated with the Source Network.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/aws-sdk-drs/types.rb', line 3151 class SourceNetwork < Struct.new( :source_network_id, :source_vpc_id, :arn, :tags, :replication_status, :replication_status_details, :cfn_stack_name, :source_region, :source_account_id, :last_recovery, :launched_vpc_id) SENSITIVE = [:tags, :replication_status_details, :cfn_stack_name] include Aws::Structure end |