Class: Aws::Drs::Types::SourceServer
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::SourceServer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#agent_version ⇒ String
The version of the DRS agent installed on the source server.
-
#arn ⇒ String
The ARN of the Source Server.
-
#data_replication_info ⇒ Types::DataReplicationInfo
The Data Replication Info of the Source Server.
-
#last_launch_result ⇒ String
The status of the last recovery launch of this Source Server.
-
#life_cycle ⇒ Types::LifeCycle
The lifecycle information of this Source Server.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance associated with this Source Server.
-
#replication_direction ⇒ String
Replication direction of the Source Server.
-
#reversed_direction_source_server_arn ⇒ String
For EC2-originated Source Servers which have been failed over and then failed back, this value will mean the ARN of the Source Server on the opposite replication direction.
-
#source_cloud_properties ⇒ Types::SourceCloudProperties
Source cloud properties of the Source Server.
-
#source_network_id ⇒ String
ID of the Source Network which is protecting this Source Server’s network.
-
#source_properties ⇒ Types::SourceProperties
The source properties of the Source Server.
-
#source_server_id ⇒ String
The ID of the Source Server.
-
#staging_area ⇒ Types::StagingArea
The staging area of the source server.
-
#tags ⇒ Hash<String,String>
The tags associated with the Source Server.
Instance Attribute Details
#agent_version ⇒ String
The version of the DRS agent installed on the source server
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#arn ⇒ String
The ARN of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#data_replication_info ⇒ Types::DataReplicationInfo
The Data Replication Info of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#last_launch_result ⇒ String
The status of the last recovery launch of this Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#life_cycle ⇒ Types::LifeCycle
The lifecycle information of this Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance associated with this Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#replication_direction ⇒ String
Replication direction of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#reversed_direction_source_server_arn ⇒ String
For EC2-originated Source Servers which have been failed over and then failed back, this value will mean the ARN of the Source Server on the opposite replication direction.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#source_cloud_properties ⇒ Types::SourceCloudProperties
Source cloud properties of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#source_network_id ⇒ String
ID of the Source Network which is protecting this Source Server’s network.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#source_properties ⇒ Types::SourceProperties
The source properties of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#staging_area ⇒ Types::StagingArea
The staging area of the source server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the Source Server.
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-drs/types.rb', line 3314 class SourceServer < Struct.new( :source_server_id, :arn, :tags, :recovery_instance_id, :last_launch_result, :data_replication_info, :life_cycle, :source_properties, :staging_area, :source_cloud_properties, :replication_direction, :reversed_direction_source_server_arn, :source_network_id, :agent_version) SENSITIVE = [:tags] include Aws::Structure end |