Class: Aws::Drs::Types::SourceServer
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::SourceServer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Source Server.
-
#data_replication_info ⇒ Types::DataReplicationInfo
The Data Replication Info of the Source Server.
-
#last_launch_result ⇒ String
The status of the last recovery launch of this Source Server.
-
#life_cycle ⇒ Types::LifeCycle
The lifecycle information of this Source Server.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance associated with this Source Server.
-
#replication_direction ⇒ String
Replication direction of the Source Server.
-
#reversed_direction_source_server_arn ⇒ String
For EC2-originated Source Servers which have been failed over and then failed back, this value will mean the ARN of the Source Server on the opposite replication direction.
-
#source_cloud_properties ⇒ Types::SourceCloudProperties
Source cloud properties of the Source Server.
-
#source_properties ⇒ Types::SourceProperties
The source properties of the Source Server.
-
#source_server_id ⇒ String
The ID of the Source Server.
-
#staging_area ⇒ Types::StagingArea
The staging area of the source server.
-
#tags ⇒ Hash<String,String>
The tags associated with the Source Server.
Instance Attribute Details
#arn ⇒ String
The ARN of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#data_replication_info ⇒ Types::DataReplicationInfo
The Data Replication Info of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#last_launch_result ⇒ String
The status of the last recovery launch of this Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#life_cycle ⇒ Types::LifeCycle
The lifecycle information of this Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance associated with this Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#replication_direction ⇒ String
Replication direction of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#reversed_direction_source_server_arn ⇒ String
For EC2-originated Source Servers which have been failed over and then failed back, this value will mean the ARN of the Source Server on the opposite replication direction.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_cloud_properties ⇒ Types::SourceCloudProperties
Source cloud properties of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_properties ⇒ Types::SourceProperties
The source properties of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#staging_area ⇒ Types::StagingArea
The staging area of the source server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the Source Server.
2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-drs/types.rb', line 2237 class SourceServer < Struct.new( :arn, :data_replication_info, :last_launch_result, :life_cycle, :recovery_instance_id, :replication_direction, :reversed_direction_source_server_arn, :source_cloud_properties, :source_properties, :source_server_id, :staging_area, :tags) SENSITIVE = [:tags] include Aws::Structure end |