Class: Aws::Drs::Types::SourceServer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Source Server.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#data_replication_infoTypes::DataReplicationInfo

The Data Replication Info of the Source Server.



2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#last_launch_resultString

The status of the last recovery launch of this Source Server.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#life_cycleTypes::LifeCycle

The lifecycle information of this Source Server.

Returns:



2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#recovery_instance_idString

The ID of the Recovery Instance associated with this Source Server.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#source_propertiesTypes::SourceProperties

The source properties of the Source Server.



2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

The tags associated with the Source Server.

Returns:

  • (Hash<String,String>)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/aws-sdk-drs/types.rb', line 2226

class SourceServer < Struct.new(
  :arn,
  :data_replication_info,
  :last_launch_result,
  :life_cycle,
  :recovery_instance_id,
  :source_properties,
  :source_server_id,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end