Class: Aws::Drs::Types::StartFailbackLaunchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartFailbackLaunchRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass StartFailbackLaunchRequest data as a hash:
{
recovery_instance_i_ds: ["RecoveryInstanceID"], # required
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#recovery_instance_i_ds ⇒ Array<String>
The IDs of the Recovery Instance whose failback launch we want to request.
-
#tags ⇒ Hash<String,String>
The tags to be associated with the failback launch Job.
Instance Attribute Details
#recovery_instance_i_ds ⇒ Array<String>
The IDs of the Recovery Instance whose failback launch we want to request.
2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-drs/types.rb', line 2260 class StartFailbackLaunchRequest < Struct.new( :recovery_instance_i_ds, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be associated with the failback launch Job.
2260 2261 2262 2263 2264 2265 |
# File 'lib/aws-sdk-drs/types.rb', line 2260 class StartFailbackLaunchRequest < Struct.new( :recovery_instance_i_ds, :tags) SENSITIVE = [:tags] include Aws::Structure end |