Class: Aws::Drs::Types::StartRecoveryPlanExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartRecoveryPlanExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique string provided to ensure request idempotency.
-
#mode ⇒ String
The execution mode (
DRILLorRECOVERY). -
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan to execute.
-
#source_servers ⇒ Array<Types::RecoveryPlanExecutionSourceServer>
Optional list of source servers with specific recovery snapshots.
-
#tags ⇒ Hash<String,String>
The tags to apply to the Recovery Plan execution.
Instance Attribute Details
#client_token ⇒ String
A unique string provided to ensure request idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
4453 4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-drs/types.rb', line 4453 class StartRecoveryPlanExecutionRequest < Struct.new( :recovery_plan_arn, :mode, :client_token, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#mode ⇒ String
The execution mode (DRILL or RECOVERY).
4453 4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-drs/types.rb', line 4453 class StartRecoveryPlanExecutionRequest < Struct.new( :recovery_plan_arn, :mode, :client_token, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#recovery_plan_arn ⇒ String
The ARN of the Recovery Plan to execute.
4453 4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-drs/types.rb', line 4453 class StartRecoveryPlanExecutionRequest < Struct.new( :recovery_plan_arn, :mode, :client_token, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_servers ⇒ Array<Types::RecoveryPlanExecutionSourceServer>
Optional list of source servers with specific recovery snapshots. If not provided, the latest snapshot is used for each server.
4453 4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-drs/types.rb', line 4453 class StartRecoveryPlanExecutionRequest < Struct.new( :recovery_plan_arn, :mode, :client_token, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the Recovery Plan execution.
4453 4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-drs/types.rb', line 4453 class StartRecoveryPlanExecutionRequest < Struct.new( :recovery_plan_arn, :mode, :client_token, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |