Class: Aws::Drs::Types::StartRecoveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass StartRecoveryRequest data as a hash:

{
  is_drill: false,
  source_servers: [ # required
    {
      recovery_snapshot_id: "RecoverySnapshotID",
      source_server_id: "SourceServerID", # required
    },
  ],
  tags: {
    "TagKey" => "TagValue",
  },
}

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#is_drillBoolean

Whether this Source Server Recovery operation is a drill or not.

Returns:

  • (Boolean)


2579
2580
2581
2582
2583
2584
2585
# File 'lib/aws-sdk-drs/types.rb', line 2579

class StartRecoveryRequest < Struct.new(
  :is_drill,
  :source_servers,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#source_serversArray<Types::StartRecoveryRequestSourceServer>

The Source Servers that we want to start a Recovery Job for.



2579
2580
2581
2582
2583
2584
2585
# File 'lib/aws-sdk-drs/types.rb', line 2579

class StartRecoveryRequest < Struct.new(
  :is_drill,
  :source_servers,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be associated with the Recovery Job.

Returns:

  • (Hash<String,String>)


2579
2580
2581
2582
2583
2584
2585
# File 'lib/aws-sdk-drs/types.rb', line 2579

class StartRecoveryRequest < Struct.new(
  :is_drill,
  :source_servers,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end