Class: Aws::Drs::Types::StartRecoveryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartRecoveryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass StartRecoveryRequest data as a hash:
{
is_drill: false,
source_servers: [ # required
{
recovery_snapshot_id: "RecoverySnapshotID",
source_server_id: "SourceServerID", # required
},
],
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[:tags]
Instance Attribute Summary collapse
-
#is_drill ⇒ Boolean
Whether this Source Server Recovery operation is a drill or not.
-
#source_servers ⇒ Array<Types::StartRecoveryRequestSourceServer>
The Source Servers that we want to start a Recovery Job for.
-
#tags ⇒ Hash<String,String>
The tags to be associated with the Recovery Job.
Instance Attribute Details
#is_drill ⇒ Boolean
Whether this Source Server Recovery operation is a drill or not.
2579 2580 2581 2582 2583 2584 2585 |
# File 'lib/aws-sdk-drs/types.rb', line 2579 class StartRecoveryRequest < Struct.new( :is_drill, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#source_servers ⇒ Array<Types::StartRecoveryRequestSourceServer>
The Source Servers that we want to start a Recovery Job for.
2579 2580 2581 2582 2583 2584 2585 |
# File 'lib/aws-sdk-drs/types.rb', line 2579 class StartRecoveryRequest < Struct.new( :is_drill, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be associated with the Recovery Job.
2579 2580 2581 2582 2583 2584 2585 |
# File 'lib/aws-sdk-drs/types.rb', line 2579 class StartRecoveryRequest < Struct.new( :is_drill, :source_servers, :tags) SENSITIVE = [:tags] include Aws::Structure end |