Class: Aws::Drs::Types::StartReplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::StartReplicationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_server ⇒ Types::SourceServer
The Source Server that this action was targeted on.
Instance Attribute Details
#source_server ⇒ Types::SourceServer
The Source Server that this action was targeted on.
3371 3372 3373 3374 3375 |
# File 'lib/aws-sdk-drs/types.rb', line 3371 class StartReplicationResponse < Struct.new( :source_server) SENSITIVE = [] include Aws::Structure end |