Class: Aws::Drs::Types::UpdateFailbackReplicationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateFailbackReplicationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
-
#name ⇒ String
The name of the Failback Replication Configuration.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
-
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
Instance Attribute Details
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
3639 3640 3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-drs/types.rb', line 3639 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Failback Replication Configuration.
3639 3640 3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-drs/types.rb', line 3639 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
3639 3640 3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-drs/types.rb', line 3639 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
3639 3640 3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-drs/types.rb', line 3639 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |