Class: Aws::Drs::Types::UpdateFailbackReplicationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateFailbackReplicationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Note:
When making an API call, you may pass UpdateFailbackReplicationConfigurationRequest data as a hash:
{
bandwidth_throttling: 1,
name: "BoundedString",
recovery_instance_id: "RecoveryInstanceID", # required
use_private_ip: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
-
#name ⇒ String
The name of the Failback Replication Configuration.
-
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
-
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
Instance Attribute Details
#bandwidth_throttling ⇒ Integer
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.
2799 2800 2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-drs/types.rb', line 2799 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Failback Replication Configuration.
2799 2800 2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-drs/types.rb', line 2799 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#recovery_instance_id ⇒ String
The ID of the Recovery Instance.
2799 2800 2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-drs/types.rb', line 2799 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |
#use_private_ip ⇒ Boolean
Whether to use Private IP for the failback replication of the Recovery Instance.
2799 2800 2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-drs/types.rb', line 2799 class UpdateFailbackReplicationConfigurationRequest < Struct.new( :bandwidth_throttling, :name, :recovery_instance_id, :use_private_ip) SENSITIVE = [] include Aws::Structure end |