Class: Aws::Drs::Types::UpdateLaunchConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateLaunchConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
-
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
-
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
-
#launch_into_instance_properties ⇒ Types::LaunchIntoInstanceProperties
Launch into existing instance properties.
-
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
-
#name ⇒ String
The name of the launch configuration.
-
#post_launch_enabled ⇒ Boolean
Whether we want to enable post-launch actions for the Source Server.
-
#recovery_mode ⇒ String
Recovery mode.
-
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
-
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#launch_into_instance_properties ⇒ Types::LaunchIntoInstanceProperties
Launch into existing instance properties.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the launch configuration.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to enable post-launch actions for the Source Server.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#recovery_mode ⇒ String
Recovery mode.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-drs/types.rb', line 3848 class UpdateLaunchConfigurationRequest < Struct.new( :source_server_id, :name, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :post_launch_enabled, :launch_into_instance_properties, :recovery_mode) SENSITIVE = [] include Aws::Structure end |