Class: Aws::Drs::Types::UpdateLaunchConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateLaunchConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
-
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
-
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
-
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
-
#name ⇒ String
The name of the launch configuration.
-
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
-
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Whether we should copy the Private IP of the Source Server to the Recovery Instance.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
The state of the Recovery Instance in EC2 after the recovery operation.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
The licensing configuration to be used for this launch configuration.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the launch configuration.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#source_server_id ⇒ String
The ID of the Source Server that we want to retrieve a Launch Configuration for.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.
2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-drs/types.rb', line 2653 class UpdateLaunchConfigurationRequest < Struct.new( :copy_private_ip, :copy_tags, :launch_disposition, :licensing, :name, :source_server_id, :target_instance_type_right_sizing_method) SENSITIVE = [] include Aws::Structure end |