Class: Aws::Drs::Types::UpdateLaunchConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-drs/types.rb

Overview

Note:

When making an API call, you may pass UpdateLaunchConfigurationRequest data as a hash:

{
  copy_private_ip: false,
  copy_tags: false,
  launch_disposition: "STOPPED", # accepts STOPPED, STARTED
  licensing: {
    os_byol: false,
  },
  name: "SmallBoundedString",
  source_server_id: "SourceServerID", # required
  target_instance_type_right_sizing_method: "NONE", # accepts NONE, BASIC
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_private_ipBoolean

Whether we should copy the Private IP of the Source Server to the Recovery Instance.

Returns:

  • (Boolean)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#copy_tagsBoolean

Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.

Returns:

  • (Boolean)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#launch_dispositionString

The state of the Recovery Instance in EC2 after the recovery operation.

Returns:

  • (String)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#licensingTypes::Licensing

The licensing configuration to be used for this launch configuration.

Returns:



2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the launch configuration.

Returns:

  • (String)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#source_server_idString

The ID of the Source Server that we want to retrieve a Launch Configuration for.

Returns:

  • (String)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end

#target_instance_type_right_sizing_methodString

Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.

Returns:

  • (String)


2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/aws-sdk-drs/types.rb', line 2597

class UpdateLaunchConfigurationRequest < Struct.new(
  :copy_private_ip,
  :copy_tags,
  :launch_disposition,
  :licensing,
  :name,
  :source_server_id,
  :target_instance_type_right_sizing_method)
  SENSITIVE = []
  include Aws::Structure
end