Class: Aws::Drs::Types::UpdateLaunchConfigurationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Drs::Types::UpdateLaunchConfigurationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-drs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_private_ip ⇒ Boolean
Copy private IP.
-
#copy_tags ⇒ Boolean
Copy tags.
-
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
-
#launch_configuration_template_id ⇒ String
Launch Configuration Template ID.
-
#launch_disposition ⇒ String
Launch disposition.
-
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
-
#licensing ⇒ Types::Licensing
Licensing.
-
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
-
#recovery_mode ⇒ String
Recovery mode.
-
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
Instance Attribute Details
#copy_private_ip ⇒ Boolean
Copy private IP.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#copy_tags ⇒ Boolean
Copy tags.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#export_bucket_arn ⇒ String
S3 bucket ARN to export Source Network templates.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#launch_configuration_template_id ⇒ String
Launch Configuration Template ID.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#launch_disposition ⇒ String
Launch disposition.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#launch_into_source_instance ⇒ Boolean
DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#licensing ⇒ Types::Licensing
Licensing.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#post_launch_enabled ⇒ Boolean
Whether we want to activate post-launch actions.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#recovery_mode ⇒ String
Recovery mode.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#target_instance_type_right_sizing_method ⇒ String
Target instance type right-sizing method.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-drs/types.rb', line 3907 class UpdateLaunchConfigurationTemplateRequest < Struct.new( :launch_configuration_template_id, :launch_disposition, :target_instance_type_right_sizing_method, :copy_private_ip, :copy_tags, :licensing, :export_bucket_arn, :post_launch_enabled, :launch_into_source_instance, :recovery_mode) SENSITIVE = [] include Aws::Structure end |